@@ -19,7 +19,7 @@
 # include <fcntl.h>
 #endif
 #include <sys/file.h>
-#include <syslog.h>
+#include "zsyslog.h"
 
 #define	SMTPSERVER	"smtpserver"
 #define	ROUTER		"router"
@@ -412,16 +412,11 @@ otherprog:
 		  fprintf(stderr, "%s: cannot submit mail (err# %d)!\n",
 			  zmailer, errno);
 
-		  openlog("sendmail", LOG_PID, LOG_MAIL);
+		  zopenlog("sendmail", LOG_PID, LOG_MAIL);
 
 		  errno = n;
-		  syslog(
-#ifdef	LOG_SALERT
-			 LOG_SALERT
-#else  /* LOG_SALERT */
-			 LOG_ALERT
-#endif /* LOG_SALERT */
-			 , "cannot submit mail for uid %d: %m", uid);
+		  zsyslog((LOG_SALERT, "cannot submit mail for uid %d: %m",
+			   uid));
 		  mfp = deadletter(uid);
 		}
 		if (truid != uid) {
