@@ -55,7 +55,9 @@
 # ifndef __STDC__
 #  define __(x) ()
 #  ifdef __GNUC__
-#   define const    __const
+#   ifndef const
+#    define const    __const
+#   endif
 #   define volatile __volatile
 #  else
 #   define const
