@@ -7,15 +7,19 @@
 #  define __(x) ()
 # endif
 #endif
-
-/* bcopy.c */
-extern void bcopy __((char *from, char *to, int len));
+#ifndef ___
+# ifdef __STDC__
+#  define ___(x) x
+# else
+#  define ___(x) 
+# endif
+#endif
 
 /* fullname.c */
 extern char *fullname __((char *s, char buf[], int buflen, char *up));
 
 /* getopt.c */
-extern int getopt __((int argc, char *argv[], char *optstring));
+extern int getopt __((int argc, char * ___(const) *argv, const char *optstring));
 
 /* getzenv.c */
 extern int   readzenv __((char *file));
@@ -46,3 +50,12 @@ extern int getmyhostname __((char *namebuf, int len));
 #ifndef HAVE_SETVBUF
 exten int setvbuf __((FILE *fp, char *buf, int type, int size));
 #endif
+
+/* inet_ntop() & inet_pton() */
+extern const char *inet_ntop __((const int, const u_char *, char *, size_t));
+extern       int   inet_pton __((const int, const void *, u_char *));
+extern       int   getaddrinfo __((const char *, const char *, const struct addrinfo *, struct addrinfo **));
+extern       int   getnameinfo __((const struct sockaddr *, size_t, char *, size_t, char *, size_t, int));
+extern       void  freeaddrinfo __((struct addrinfo *));
+extern       char *gai_strerror __((int));
+extern struct hostent *gethostbyname2 __((const char *, int));
