@@ -100,7 +100,7 @@ extern char *rfc822tz __((struct tm *ts, int prettyname));
 extern char *rfc822date __((time_t *timep));
 
 /* rfc822scan.c */
-extern int    hdr_status __((u_char *cp, u_char *lbuf, int n));
+extern int    hdr_status __((u_char *cp, u_char *lbuf, int n, int octo));
 extern u_long _hdr_compound __((u_char *cp, long n, u_char cstart, u_char cend,
 				TokenType type, struct token *tp,
 				struct token **tlist, struct token **tlistp));
