@@ -133,9 +133,9 @@ struct mimestate {
 /* ctlopen.c: */
 extern void            ctlfree __((struct ctldesc *dp, void *anyp));
 extern void           *ctlrealloc __((struct ctldesc *dp, void *anyp, size_t size));
-extern struct ctldesc *ctlopen __((char *file,char *channel, char *host, int *exitflag, int (*selectaddr)(),int (*matchrouter)()));
+extern struct ctldesc *ctlopen __((char *file,char *channel, char *host, int *exitflag, int (*selectaddr)(), void *saparam, int (*matchrouter)(), void *mrparam));
 extern void            ctlclose __((struct ctldesc *dp));
-extern int	       ctlsticky __((char *spec_host,char *addr_host));
+extern int	       ctlsticky __((char *spec_host,char *addr_host, void *cbparam));
 
 /* diagnostic.c: */
 extern char           *notaryacct __((int rc, char *okstr));
@@ -186,7 +186,7 @@ extern int ermdir __((char *path));
 extern int erename __((char *from, char *to));
 
 /* lockaddr.c: */
-extern int lockaddr __((int fd, char *map, long offset, int was, int new, const char *file, const char *host));
+extern int lockaddr __((int fd, char *map, long offset, int was, int new, const char *file, const char *host, const int mypid));
 
 /* markoff.c: */
 extern int markoff __((char *filecontents, int bytesleft, long offsets[], char *filename));
@@ -233,7 +233,7 @@ extern void taspoolid __((char *buf, int buflen, time_t mtime, char *path));
 
 /* tasyslog.c */
 extern void tatimestr __((char *buf, int dt));
-extern void tasyslog __((struct rcpt *rp, int xdelay, char *wtthost, char *stat, char *msg));
+extern void tasyslog __((struct rcpt *rp, int xdelay, char *wtthost, char *wttip, char *stat, char *msg));
 
 #ifndef CISTREQ
 #define  CISTREQ(x, y)      (cistrcmp((char *)(x), (char *)(y)) == 0)
