@@ -16,22 +16,25 @@
  * XX: possibly too much done inside a signal handler?
  */
 
+extern char *progname;
+extern char *logfn;
+
 int
-loginit()
+loginit(sig)
+     int sig;
 {
-	extern char *log, *progname;
 	int flags;
 
-	if (log == NULL)
+	if (logfn == NULL)
 		return -1;
 	fflush(stdout);
 	rewind(stdout);
 	fflush(stderr);
 	rewind(stderr);
-	if (freopen(log, "a+", stdout) != stdout
+	if (freopen(logfn, "a+", stdout) != stdout
 	    || dup2(FILENO(stdout), FILENO(stderr)) < 0) {	/* sigh */
 		/* XX: stderr might be closed at this point... */
-		fprintf(stderr, "%s: cannot open log: %s\n", progname, log);
+		fprintf(stderr, "%s: cannot open log: %s\n", progname, logfn);
 		return -1;
 	}
 #if	defined(F_SETFL) && defined(O_APPEND)
