@@ -32,22 +32,38 @@
 #ifdef HAVE_SYS_SOCKET_H
 #include <sys/socket.h>
 #endif
+#if defined(__svr4__) && defined(__sun)
+# define BSD_COMP /* Damn Solaris, and its tricks... */
+#endif
+#include <sys/ioctl.h>
 #ifdef HAVE_STDLIB_H
 #include <stdlib.h>
 #endif
 #include <netdb.h>
+#ifndef EAI_AGAIN
+# include "netdb6.h" /* IPv6 API stuff */
+#endif
 #include <netinet/in.h>
+#ifdef HAVE_NETINET_IN6_H
+# include <netinet/in6.h>
+#endif
+#ifdef HAVE_NETINET6_IN6_H
+# include <netinet6/in6.h>
+#endif
+#ifdef HAVE_LINUX_IN6_H
+# include <linux/in6.h>
+#endif
 #include <arpa/inet.h>
 #include <string.h>
 
-extern char *getzenv __((const char *));
+extern char  *getzenv     __((const char *));
 
 /* hostent.c */
-extern void hp_init __((struct hostent *hp));
-extern void hp_setalist __((struct hostent *hp, void **));
-extern char **hp_getaddr __((void));
+extern void   hp_init     __((struct hostent *hp));
+extern void   hp_setalist __((struct hostent *hp, void **));
+extern char **hp_getaddr  __((void));
 extern char **hp_nextaddr __((void));
-extern void hp_addr_randomize __((struct hostent *hp));
+extern void   hp_addr_randomize __((struct hostent *hp));
 
 /*
 **  LOADIFADDRESSES -- load interface-specific addresses
@@ -67,12 +83,6 @@ fi
 
 #include "hostenv.h"
 
-#ifdef HAVE_SYS_SOCKET_H
-#include <sys/socket.h>
-#endif
-
-#include <netinet/in.h>
-
 struct rtentry; /* Dummies for BSD systems */
 struct mbuf;
 #include <arpa/inet.h>
@@ -86,14 +96,28 @@ struct sockaddr ***sockaddrp;
 #ifdef SIOCGIFCONF
 	int s;
 	int i;
-	int ifcount;
+	int ifcount = 0;
+	int af = AF_INET;
         struct ifconf ifc;
 	int ifbufsize = 4 * sizeof(struct ifreq) + 4;
 	char *interfacebuf = (void*)malloc(ifbufsize);
+	struct sockaddr **sap;
 
-	s = socket(AF_INET, SOCK_DGRAM, 0);
-	if (s < 0)
-		return -1;
+	sap = (void*)malloc(sizeof(struct sockaddr*) * (ifcount + 2));
+	if (! sap) {
+	  close(s);
+	  free(interfacebuf);
+	  return -3; /* UAARGH! */
+	}
+
+other_socktype:
+
+	s = socket(af, SOCK_DGRAM, 0);
+	if (s < 0) {
+	  free(interfacebuf);
+	  free(sap);
+	  return -1;
+	}
 
 	/* Redo the buffer size increase until we get response size to
 	   be something of LESS THAN the buffer size minus two-times
@@ -118,7 +142,8 @@ struct sockaddr ***sockaddrp;
 	  if (ioctl(s, SIOCGIFCONF, (char *)&ifc) < 0) {
 		close(s);
 		free(interfacebuf);
-		return -1;
+		free(sap);
+		return -2;
 	  }
 
 	  if (ifc.ifc_len < (ifbufsize - 2*sizeof(struct ifreq)))
@@ -130,13 +155,6 @@ struct sockaddr ***sockaddrp;
 
 	/* Count how many addresses listed */
 
-	ifcount = 0;
-	*sockaddrp = (void*)malloc(sizeof(struct sockaddr*) * (ifcount + 1));
-	if (! *sockaddrp) {
-	  close(s);
-	  return -1; /* UAARGH! */
-	}
-
 	for (i = 0; i < ifc.ifc_len; ) {
 
 	  struct ifreq *ifr = (struct ifreq *) &ifc.ifc_buf[i];
@@ -186,11 +204,11 @@ struct sockaddr ***sockaddrp;
 	    continue;
 #endif
 
-	  *sockaddrp = (void*)realloc(*sockaddrp,
-				      sizeof(struct sockaddr*) * (ifcount + 1));
-	  if (! *sockaddrp) {
+	  sap = (void*)realloc(sap, sizeof(struct sockaddr*) * (ifcount + 2));
+	  if (! sap) {
 	    close(s);
-	    return -1; /* UAARGH! */
+	    free(interfacebuf);
+	    return -4; /* UAARGH! */
 	  }
 
 	  /* XX: Use sa_len on BSD44 ??? */
@@ -198,73 +216,51 @@ struct sockaddr ***sockaddrp;
 	    struct sockaddr_in *si4 = (void*)malloc(sizeof(*si4));
 	    if (si4 == NULL)
 	      break;
-	    (*sockaddrp)[ifcount] = (struct sockaddr*)si4;
+	    /* pick the whole sockaddr package! */
+	    memcpy(si4, &ifr->ifr_addr, sizeof(struct sockaddr_in));
+	    sap[ifcount] = (struct sockaddr*)si4;
 	  }
 #ifdef AF_INET6
 	  if (sa->sa_family == AF_INET6) {
 	    struct sockaddr_in6 *si6 = (void*)malloc(sizeof(*si6));
 	    if (si6 == NULL)
 	      break;
-	    (*sockaddrp)[ifcount] = (struct sockaddr*)si6;
+
+	    /* XX: MUST DO AN  ioctl(s, SIOCGIFADDR, ...) HERE ! */
+
+	    /* pick the whole sockaddr package! */
+	    memcpy(si6, &ifr->ifr_addr, sizeof(struct sockaddr_in6));
+	    sap[ifcount] = (struct sockaddr*)si6;
 	  }
 #endif
 	  ++ifcount;
 	}
+	sap[ifcount] = NULL;
 	close(s);
 
+#ifdef AF_INET6
+	if (af != AF_INET6) {
+	  af = AF_INET6;
+	  goto other_socktype;
+	}
+#endif
+
+	free(interfacebuf);
+	*sockaddrp = sap;
+
 	return ifcount;
 #else
 	return -1;
 #endif
 }
 
-#ifdef TESTMODE
+#ifndef TESTMODE /* We test ONLY of  loadifaddresses() routine! */
 
-extern char *inet_ntoa __((struct in_addr));
-
-char *progname = "selfaddrstest";
-
-int main(argc,argv)
-int argc;
-char *argv[];
-{
-  int cnt, i;
-  struct sockaddr **sa;
-
-  cnt = loadifaddresses(&sa);
-
-  printf("loadifaddresses rc=%d\n", cnt);
-
-  for (i = 0; i < cnt; ++i) {
-    struct in_addr ia;
-    switch(sa[i].sa_family) {
-    case AF_INET:
-      ia = ((struct sockaddr_in *) sa)[i].sin_addr;
-      printf("IPv4: [%s]\n", inet_ntoa(ia));
-      break;
-#ifdef AF_INET6
-    case AF_INET6:
-      printf("IPv6: ???\n");
-      break;
-#endif
-    default:
-      printf("Unknown socket address family: %d\n", sa[i].sa_family);
-      break;
-    }
-  }
-
-  free(sa);
-
-  return 0;
-}
-#endif /* TESTMODE */
-
-
-int nmyaddrs = 0;
-struct sockaddr  **myaddrs = NULL;
+static             int    nmyaddrs = 0;
+static struct sockaddr  ** myaddrs = NULL;
 
 static void
-stachmyaddress(host)
+stashmyaddress(host)
 	char *host;
 {
 	int naddrs;
@@ -338,10 +334,10 @@ stachmyaddress(host)
 	}
 	if (myaddrs == NULL) {
 	  nmyaddrs = 0;
-	  myaddrs = malloc((nmyaddrs + naddrs) * sizeof(struct sockaddr*));
+	  myaddrs = malloc((nmyaddrs + naddrs +1) * sizeof(struct sockaddr*));
 	} else
 	  myaddrs = realloc(myaddrs,
-			    (nmyaddrs + naddrs) * sizeof(struct sockaddr*));
+			    (nmyaddrs + naddrs +1) * sizeof(struct sockaddr*));
 
 	if (!myaddrs) return; /* Uurgh.... */
 
@@ -371,27 +367,35 @@ stachmyaddress(host)
 	  }
 #endif
 	}
+	myaddrs[nmyaddrs] = NULL;
 }
 
 void
-stachmyaddresses(host)
+stashmyaddresses(host)
 char *host;
 {
 	char *s1, *s2, *zenv;
 	struct sockaddr **sa;
 	int sacnt;
 
+	/* Clear them all away */
+	if (myaddrs != NULL) {
+	  int i;
+	  for (i = 0; i < nmyaddrs; ++i)
+	    if (myaddrs[i] != NULL)
+	      free(myaddrs[i]);
+	  free(myaddrs);
+	  myaddrs = NULL;
+	  nmyaddrs = 0;
+	}
+
+	/* Now start fillig -- interface addresses, if you can get them */
+
 	sacnt = loadifaddresses(&sa);
+
 	if (sacnt > 0) {
 	  /* Okay, we GOT some addresses, I bet we got them all!
-	     (All that we currently have active interfaces!) */
-	  if (myaddrs != NULL) {
-	    int i;
-	    for (i = 0; i < nmyaddrs; ++i)
-	      free(myaddrs[i]);
-	    free(myaddrs);
-	    myaddrs = NULL;
-	  }
+	     (All interfaces that we currently have active!) */
 	  myaddrs = sa;
 	  nmyaddrs = sacnt;
 
@@ -402,13 +406,14 @@ char *host;
 
 	zenv = getzenv("SELFADDRESSES");
 
-	stachmyaddress(host);
+	if (host && *host)
+	  stashmyaddress(host);
 
 	s1 = zenv;
 	while (s1) {
 	  s2 = strchr(s1,',');
 	  if (s2) *s2 = 0;
-	  stachmyaddress(s1);
+	  stashmyaddress(s1);
 	  if (s2) *s2 = ',';
 	  if (s2)
 	    s1 = s2+1;
@@ -505,3 +510,44 @@ matchmyaddresses(hp)
 	}
 	return 0;
 }
+#endif /* TESTMODE */
+
+#ifdef TESTMODE
+
+char *progname = "selfaddrstest";
+
+int main(argc,argv)
+int argc;
+char *argv[];
+{
+  int cnt, i;
+  struct sockaddr **sa;
+  char buf[80];
+
+  cnt = loadifaddresses(&sa);
+
+  printf("loadifaddresses rc=%d\n", cnt);
+
+  for (i = 0; i < cnt; ++i) {
+    switch(sa[i]->sa_family) {
+    case AF_INET:
+      inet_ntop(AF_INET, &((struct sockaddr_in **) sa)[i]->sin_addr, buf, sizeof(buf));
+      printf("IPv4: [%s]\n", buf);
+      break;
+#ifdef AF_INET6
+    case AF_INET6:
+      inet_ntop(AF_INET6, &((struct sockaddr_in6 **) sa)[i]->sin6_addr, buf, sizeof(buf));
+      printf("IPv6: [ipv6.%s]\n");
+      break;
+#endif
+    default:
+      printf("Unknown socket address family: %d\n", sa[i]->sa_family);
+      break;
+    }
+  }
+
+  free(sa);
+
+  return 0;
+}
+#endif /* TESTMODE */
