@@ -309,14 +309,26 @@ mail_abort(fp)
  * Close the message file on the indicated stream and submit it to the mailer.
  */
 
-int
-mail_close(fp)
+int mail_close(fp)
 	FILE *fp;
+{
+	int ino;
+	time_t mtime;
+
+	return _mail_close_(fp, &ino, &mtime);
+}
+
+
+int
+_mail_close_(fp,inop, mtimep)
+	FILE *fp;
+	int *inop;
+	time_t *mtimep;
 {
 	char **messagep, *message, *nmessage, *msgbase;
 	char *routerdir;
 	char *routerdirs, *s = NULL;
-	int eno;
+	struct stat stb;
 
 	if (postoffice == NULL) {
 		fprintf(stderr, "mail_close: called out of order!\n");
@@ -371,9 +383,13 @@ mail_close(fp)
 	    int i = mail_priority;
 	    char *rd = routerdirs;
 	    char *ord = routerdir;
-	    struct stat stb;
+#ifdef HAVE_ALLOCA
+	    nmessage = alloca(strlen(postoffice)+
+			      strlen(routerdirs)+3+strlen(msgbase));
+#else
 	    nmessage = mail_alloc(strlen(postoffice)+
 				  strlen(routerdirs)+3+strlen(msgbase));
+#endif
 	    /* There are some defined!   A ":" separated list of strings */
 
 	    /* mail_priority == 1 pics first, 2 pics second, ..
@@ -405,8 +421,13 @@ mail_close(fp)
 	}
 	/* Assert postoffice != NULL */
 	if (nmessage == NULL) {
+#ifdef HAVE_ALLOCA
+	  nmessage = alloca(strlen(postoffice)+
+			    strlen(routerdir)+strlen(msgbase)+2+1);
+#else
 	  nmessage = mail_alloc(strlen(postoffice)+
 				strlen(routerdir)+strlen(msgbase)+2+1);
+#endif
 	  sprintf(nmessage, "%s/%s/%s", postoffice, routerdir, msgbase);
 	} else {
 	  s = strchr(routerdir,':');
@@ -422,17 +443,26 @@ mail_close(fp)
 	 */
 
 	if (link(message, nmessage) != 0) {
-		eno = errno;
-		fprintf(stderr, "link(\"%s\", \"%s\"): errno %d\n",
-				message, nmessage, errno);
-		mail_free(message);
-		mail_free(nmessage);
-		errno = eno;
-		return -1;
+	  int eno = errno;
+	  fprintf(stderr, "link(\"%s\", \"%s\"): errno %d\n",
+		  message, nmessage, errno);
+	  mail_free(message);
+	  mail_free(nmessage);
+	  errno = eno;
+	  return -1;
 	}
+#ifndef HAVE_ALLOCA
 	mail_free(nmessage);
+#endif
+	stat(message, &stb);
 	unlink(message);
 	mail_free(message);
+
+	if (inop != NULL)
+	  *inop = stb.st_ino;
+	if (mtimep != NULL)
+	  *mtimep = stb.st_mtime;
+
 	return 0;
 }
 
