@@ -13,6 +13,8 @@
 
 /* Tuned to be part of ZMailer -- #include "zmsignal.h" .. */
 
+#define USENONBLOCK 1
+
 #include "hostenv.h"
 #include <stdio.h>
 #include "zmsignal.h"
@@ -22,6 +24,15 @@
 #include <fcntl.h> /*XXX*/
 #include <sys/socket.h>
 #include <netinet/in.h>
+#ifdef HAVE_NETINET_IN6_H
+# include <netinet/in6.h>
+#endif
+#ifdef HAVE_NETINET6_IN6_H
+# include <netinet6/in6.h>
+#endif
+#ifdef HAVE_LINUX_IN6_H
+# include <linux/in6.h>
+#endif
 #include <ctype.h>
 #include <errno.h>
 #ifdef	ISC
@@ -97,10 +108,12 @@ int *sockp;
     CLORETS(-1);
   }
 
+#if USENONBLOCK
   if ((fl = fcntl(s, F_GETFL, 0)) == -1)
     CLORETS(-1);
   if (fcntl(s, F_SETFL, FNDELAY | fl) == -1)
     CLORETS(-1);
+#endif
 
   *sockp = s; /* Following connect may take non-trivial time,
 		 and we may be jumping around with SIGALRM,
@@ -133,7 +146,7 @@ int *sockp;
 }
 
 
-char *ident_sockuser2(s,local,remote,realbuf,realbuflen)
+static char *ident_sockuser2(s,local,remote,realbuf,realbuflen)
 int s;
 unsigned short local;
 unsigned short remote;
@@ -157,6 +170,7 @@ int realbuflen;
   FD_SET(s,&wfds);
   select(s + 1,(fd_set *) 0,&wfds,(fd_set *) 0,(struct timeval *) 0);
   /* now s is writable */
+#if USENONBLOCK
   if ((fl = fcntl(s,F_GETFL,0)) == -1) {
     signal(SIGPIPE, old_sig);
     CLORETS("SOCKFCNTL1");
@@ -165,6 +179,7 @@ int realbuflen;
     signal(SIGPIPE, old_sig);
     CLORETS("SOCKFCNTL2");
   }
+#endif
   buf = realbuf;
   sprintf(buf,"%u , %u\r\n",(unsigned int) remote,(unsigned int) local);
   /* note the reversed order---the example in RFC 931 is misleading */
@@ -174,10 +189,12 @@ int realbuflen;
       signal(SIGPIPE, old_sig);
       saveerrno = errno;
       close(s);
-      if (errno == ECONNREFUSED)
+      if (errno == ECONNREFUSED || errno == EPIPE)
 	return "NO-IDENT-SERVICE";
-      else
-	return "SOCKWRITE";
+      else {
+	sprintf(realbuf,"SOCKWRITE-%d", errno);
+	return realbuf;
+      }
     } else {
       buf += w;
       buflen -= w;
@@ -195,7 +212,8 @@ int realbuflen;
     CLORETS("SOCKREAD");
   *buf = 0;
 
-  if (sscanf(realbuf,"%hd,%hd: USERID :%*[^:]:%s",&rremote,&rlocal,realbuf) < 3) {
+  if (sscanf(realbuf,"%hd,%hd: USERID :%*[^:]:%s",
+	     &rremote,&rlocal,realbuf) < 3) {
     close(s);
     errno = EIO;
     /* makes sense, right? well, not when USERID failed to match ERROR */
@@ -214,11 +232,17 @@ int realbuflen;
 }
 
 
+static void sig_alrm (sig)
+	int sig;
+{
+	longjmp(jmpalarm,1);
+}
+
 char *ident_tcpuser9(af,len,inlocal,inremote,local,remote,timeout,buf,buflen)
-	int af, len;
-	int *inlocal;
+	int af, len;	/* Address family, and address size */
+	int *inlocal;		/* Addresses */
 	int *inremote;
-	unsigned short local;
+	unsigned short local;	/* Ports */
 	unsigned short remote;
 	int timeout;
 	char *buf;
@@ -229,12 +253,24 @@ char *ident_tcpuser9(af,len,inlocal,inremote,local,remote,timeout,buf,buflen)
   fd_set wfds;
   int saveerrno;
   void (*old_sig)__((int));
+  void (*old_alrm)__((int));
+  int oldival;
   char *retval;
   
-  old_sig = signal(SIGPIPE, SIG_IGN);
+  old_sig  = signal(SIGPIPE, SIG_IGN);
+  oldival  = alarm(10); /* 10 seconds until... */
+  old_alrm = signal(SIGALRM, sig_alrm);
   s = -1;
 
-  r = ident_tcpsock5(af, len, inlocal, inremote, &s);
+  if (setjmp(jmpalarm) == 0) {
+    r = ident_tcpsock5(af, len, inlocal, inremote, &s);
+  } else {
+    /* We reach here in case of alarm timer chime... */
+    if (s >= 0) close(s);
+    r = -1;
+  }
+  signal(SIGALRM, old_alrm);
+  alarm(oldival);
   if (r < 0) {
     signal(SIGPIPE, old_sig);
     return "SOCKFAULT1";
@@ -440,6 +476,7 @@ register unsigned short remote;
   FD_SET(s,&wfds);
   select(s + 1,(fd_set *) 0,&wfds,(fd_set *) 0,(struct timeval *) 0);
   /* now s is writable */
+#if USENONBLOCK
   if ((fl = fcntl(s,F_GETFL,0)) == -1) {
     signal(SIGPIPE, old_sig);
     CLORETS("SOCKFCNTL1");
@@ -448,6 +485,7 @@ register unsigned short remote;
     signal(SIGPIPE, old_sig);
     CLORETS("SOCKFCNTL2");
   }
+#endif
   buf = realbuf;
   sprintf(buf,"%u , %u\r\n",(unsigned int) remote,(unsigned int) local);
   /* note the reversed order---the example in RFC 931 is misleading */
