@@ -17,7 +17,7 @@
 #include <fcntl.h>
 #include <sys/file.h>
 
-#include "syslog.h"
+#include "zsyslog.h"
 
 /* #define static
    #define register */
@@ -1200,7 +1200,7 @@ interpret(code, eocode, entry, caller, retcodep, cdp)
 	++funclevel;
 	if (funclevel > max_interpreter_recursions) {
 	  fprintf(stderr,"zmailer: interpret: recursed more than %d levels deep on invocation!  script termination condition error ?\n",max_interpreter_recursions);
-	  syslog(LOG_EMERG,"zmailer: interpret: recursed more than %d levels deep on invocation!  script termination condition error ?\n",max_interpreter_recursions);
+	  zsyslog((LOG_EMERG,"zmailer: interpret: recursed more than %d levels deep on invocation!  script termination condition error ?\n",max_interpreter_recursions));
 	  abort(); /* excessively deep recursion - *.cf -script termination condition error ? */
 	}
 #endif	/* MAILER */
