@@ -44,7 +44,11 @@ int	real_stability = 0;
 int	maxReceived = 50;
 
 /* we want those nice tabs between the header field name and value */
+#ifdef RFC822TABS
+int	wanttabs = RFC822TABS;
+#else
 int	wanttabs = 1;
+#endif
 
 /* depending on what you postmaster wants from   $(filepriv ...) to see:
    022 for usual        644 or more strict,
