@@ -100,6 +100,8 @@ struct db_kind {
 { "bind",	{ RESOLV_CONF, NULL, 0, 10, 0, NULL,
 		  search_res, NULL, NULL, NULL, NULL, NULL, NULL, NULL, Nul }},
 #endif	/* HAVE_RESOLV */
+{ "selfmatch",	{ NULL, NULL, 0, 0, 0, NULL, search_selfmatch, NULL, NULL,
+		  NULL, print_selfmatch, count_selfmatch, NULL, NULL, Nul } },
 #ifdef	HAVE_NDBM_H
 { "ndbm",	{ NULL, NULL, 0, 10, 0, NULL, search_ndbm, close_ndbm,
 		  add_ndbm, remove_ndbm, print_ndbm, count_ndbm, owner_ndbm,
@@ -236,8 +238,20 @@ run_relation(argc, argv)
 		}
 	if (errflg || optind != argc - 1 || dbtype == NULL) {
 		fprintf(stderr,
-		"Usage: %s -t dbtype [-f file -e# -s# -blnu -d driver] name\n",
+		"Usage: %s -t dbtype[,subtype] [-f file -e# -s# -bilmnpu -d driver] name\n",
 			argv[0]);
+		fprintf(stderr,
+			"      dbtypes: ");
+		for (dbkp = &db_kinds[0];
+		     dbkp < &db_kinds[(sizeof db_kinds)/sizeof (struct db_kind)];
+		     ++dbkp) {
+		  if (dbkp->name != NULL)
+		    if (dbkp == &db_kinds[0])
+		      fprintf(stderr,"%s",dbkp->name);
+		    else
+		      fprintf(stderr,",%s",dbkp->name);
+		}
+		fprintf(stderr,"\n");
 		return 1;
 	}
 	if ((proto_config.flags & (DB_MAPTOLOWER|DB_MAPTOUPPER)) ==
