@@ -23,6 +23,15 @@
 #endif	/* BSDTYPES_H */
 
 #include <netinet/in.h>
+#ifdef HAVE_NETINET_IN6_H
+# include <netinet/in6.h>
+#endif
+#ifdef HAVE_NETINET6_IN6_H
+# include <netinet6/in6.h>
+#endif
+#ifdef HAVE_LINUX_IN6_H
+# include <linux/in6.h>
+#endif
 
 #ifdef NOERROR
 #undef NOERROR /* On Solaris 2.3 the  netinet/in.h  includes
@@ -683,7 +692,7 @@ getrrtypec(host, rrtype, ttlp, depth)
 			if (rrtype == T_ANY) {
 			  return newstring((u_char*)strsave(host));
 			}
-#ifdef AF_INET6
+#if defined(AF_INET6) && defined(INET6)
 			{
 			  char tb[80];
 			  const char *ss;
