@@ -72,7 +72,7 @@ struct headerinfo envelope_hdrs[] = {
 { "identinfo",	nilHeaderSemantics,	nilUserType,	eIdentinfo	},
 { "loginname",		UserAtDomain,	nilUserType,	ePrettyLogin	},
 { "notaryret",	nilHeaderSemantics,	nilUserType,	eNotaryRet	},
-{ "rcvdfrom",		DomainName,	nilUserType,	eRcvdFrom	},
+{ "rcvdfrom",		UserAtDomain,	nilUserType,	eRcvdFrom	},
 { "to",			AddressList,	Recipient,	eTo		},
 { "todsn",	nilHeaderSemantics,	Recipient,	eToDSN		},
 { "user",		Mailbox,	nilUserType,	eUser		},
