@@ -300,6 +300,9 @@ modp_ndbm(sip)
 				sip->file);
 		return 0;
 	}
+	if (stbuf.st_nlink == 0)
+		return 1;	/* Unlinked underneath of us! */
+
 	symid = symbol((u_char *)sip->file);
 	spl = sp_lookup(symid, spt_modcheck);
 	if (spl != NULL) {
