@@ -17,6 +17,7 @@
 extern FILE *fpmap();
 extern int deferit, cistrcmp();
 extern void v_set();
+extern char *skip821address();
 
 #ifdef HAVE_MMAP
 extern void seq_remap __((struct file_map *, long newsize));
@@ -143,9 +144,8 @@ reopen:
 		fm->pos = fm->offsets[mid];
 		if (mfgets(buf, sizeof (buf), fm) == NULL) return NULL;
 		
-		for (cp = (unsigned char *)buf; *cp; ++cp)
-			if (!isascii(*cp) || isspace(*cp))
-				break;
+		cp = skip821address(buf);
+
 		if (*cp == '\0')
 			*(cp+1) = '\0';
 		else
@@ -186,9 +186,9 @@ reopen:
 			}
 			break;
 		}
-		for (cp = (unsigned char *)buf; *cp; ++cp)
-			if (!isascii(*cp) || isspace(*cp))
-				break;
+
+		cp = skip821address(buf);
+
 		if (*cp == '\0')
 			*(cp+1) = '\0';
 		else
