@@ -80,7 +80,7 @@ decode_result:
 	  if (valptr[vallen] == '\n') {
 	    valptr[vallen] = '\0';
 	  }
-	  return newstring((u_char *) valptr);
+	  return newstring((u_char *) strnsave(valptr,vallen));
 	case YPERR_KEY:
 	  /* occasionally the terminating NULL is included in the key (lose!)
 	     so if we failed for "key not found" then try again with the NULL
