@@ -21,7 +21,6 @@
 
 /* various libraries, standard libc included.. */
 
-extern char	*erraddrlog;
 extern char	*gs_name;
 extern char	*monthname[];
 extern char	*myhostname;
@@ -152,7 +151,7 @@ extern int	iserrmessage __((void));
 extern int	sequencer __((struct envelope *e, char *file));
 
 /* File: rfc822hdrs.c */
-extern union misc	 hdr_scanparse __((struct envelope *e, struct header *h, int commentflag));
+extern union misc	 hdr_scanparse __((struct envelope *e, struct header *h, int commentflag, int no_line_crossing));
 extern struct header	*makeHeader __((struct sptree *db, u_char *s, int len));
 extern struct headerinfo *senderDesc __((void));
 extern void	set_pname __((struct envelope *e, struct header *h, char *s));
