@@ -19,7 +19,7 @@
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif
-#include "syslog.h"
+#include "zsyslog.h"
 
 #include "prototypes.h"
 
@@ -53,13 +53,14 @@ extern int eunlink();
 extern int erename();
 extern int getline();
 extern int nobody;
+extern int deferuid;
 extern int s_equal();
 extern long offset();
 extern void initline();
 
 static void	reject __((struct envelope *e, char *msgfile));
 
-static void	prctladdr __((struct conscell *info, FILE *fp, int cfflag, char *comment));
+static char *	prctladdr __((struct conscell *info, FILE *fp, int cfflag, char *comment));
 static void	prdsndata __((struct conscell *info, FILE *fp, int cfflag, char *comment));
 static struct conscell	*find_errto __((struct conscell *list));
 
@@ -139,8 +140,8 @@ run_rfc822(argc, argv)
 	qate = e;
 
 	if ((e->e_fp = fopen(file, "r")) == NULL) {
-		fprintf(stderr, "router: cannot open %s\n", file);
-		status = PERR_BADOPEN;
+	  fprintf(stderr, "router: cannot open %s\n", file);
+	  status = PERR_BADOPEN;
 	} else {
 	  /* XX: DEBUG STUFF! */
 	  if (FILENO(e->e_fp) < 3) {
@@ -149,15 +150,15 @@ run_rfc822(argc, argv)
 	    fflush(stderr);
 	    /* abort(); */
 	  }
-		status = PERR_OK;
-		setvbuf(e->e_fp, buf, _IOFBF, sizeof buf);
-		e->e_file = file;
-		status = makeLetter(e, 0);
+	  status = PERR_OK;
+	  setvbuf(e->e_fp, buf, _IOFBF, sizeof buf);
+	  e->e_file = file;
+	  status = makeLetter(e, 0);
 	}
 
 	if (status == PERR_OK)
-		/* passing the file is redundant but nice for backtraces */
-		status = sequencer(e, file);
+	  /* passing the file is redundant but nice for backtraces */
+	  status = sequencer(e, file);
 
 	switch (status) {
 	case PERR_OK:		/* 0 */
@@ -178,7 +179,10 @@ run_rfc822(argc, argv)
 		reject(e, "envelope");
 		break;
 	case PERR_DEFERRED:
-		defer(e, "deferred");
+		if (deferuid)
+		  defer(e, "deferuid");
+		else
+		  defer(e, "deferred");
 		break;
 	case PERR_HEADER:		/* fatal */
 		reject(e, "header");
@@ -538,10 +542,8 @@ squirrel(e, keyw, text)
 
 	fprintf(stderr, "squirrel: %d.%s saved for inspection: %s\n",
 			e->e_statbuf.st_ino, keyw, text);
-#ifdef	LOG_ERR
-	syslog(LOG_ERR, "%d.%s saved for inspection: %s\n",
-			e->e_statbuf.st_ino, keyw, text);
-#endif	/* LOG_ERR */
+	zsyslog((LOG_ERR, "%d.%s saved for inspection: %s\n",
+		 e->e_statbuf.st_ino, keyw, text));
 #ifndef	USE_ALLOCA
 	free(path);
 #endif
@@ -781,17 +783,12 @@ defer(e, why)
 	for (i = 0; erename(e->e_file, path) < 0 && i < 10 && errno != ENOENT;++i)
 		sleep(6);
 	if (i >= 10) {
-#ifdef	LOG_ALERT
-		syslog(LOG_ALERT, "cannot defer %s (%m)", e->e_file);
-#endif	/* LOG_ALERT */
-		fprintf(stderr, "cannot defer %s\n", e->e_file);
-		/* XX: make sure file is not unlink()ed in main() */
+	  zsyslog((LOG_ALERT, "cannot defer %s (%m)", e->e_file));
+	  fprintf(stderr, "cannot defer %s\n", e->e_file);
+	  /* XX: make sure file is not unlink()ed in main() */
 	} else {
-#ifdef	LOG_NOTICE
-		syslog(LOG_NOTICE, "%s; %sing deferred",
-			   e->e_messageid == NULL ? e->e_file : e->e_messageid,
-			   deferit ? "schedul" : "rout");
-#endif	/* LOG_NOTICE */
+	  zsyslog((LOG_NOTICE, "%s; %sing deferred", e->e_file,
+		   (deferit || deferuid) ? "schedul" : "rout"));
 	}
 #ifndef	USE_ALLOCA
 	free(path);
@@ -1126,6 +1123,12 @@ sequencer(e, file)
 	char vbuf[2048], verbosefile[1024];
 	char *envid;
 	char *notaryret;
+	int nrcpts = 0;
+	char *fromaddr = "?from?";
+	char *msgidstr = "?msgid?";
+	char *smtprelay = NULL;
+
+	deferuid = 0;
 
 	errors_to = NULL; /* to be gotten rid off.. */
 
@@ -1134,6 +1137,54 @@ sequencer(e, file)
 		return PERR_OK;
 	}
 
+	dprintf("Sender authentication\n");
+	e->e_trusted = isgoodguy(e->e_statbuf.st_uid);
+	dprintf("Sender is%s trusted\n", e->e_trusted ? "" : "n't");
+
+	if (deferuid)
+	  return PERR_DEFERRED;
+
+	FindEnvelope(eRcvdFrom);
+	if (e->e_trusted) {
+	  if (h != NULL)
+	    smtprelay = h->h_lines->t_pname;
+	  else {
+	    char *s = uidpwnam(e->e_statbuf.st_uid);
+	    smtprelay = strnsave("",strlen(s)+20);
+	    sprintf(smtprelay, "%s@localhost", s);
+	  }
+	} else {
+	  /* Ok, we don't trust it!  In fact we might overrule the data
+	     that the message writer coded in... */
+	  char *s, *p, *t;
+	  int totlen;
+
+	  dprintf("Message has 'rcvdfrom' envelope header, but we don't trust it!\n");
+	  s = uidpwnam(e->e_statbuf.st_uid);
+	  p = (h ? h->h_lines->t_pname : NULL);
+	  totlen = 10 + strlen(s) + 20 + (p ? strlen(p) + 10 : 0);
+	  /* t = strnsave("", totlen); */
+	  t = tmalloc(totlen); /* Alloc the space */
+	  if (h) {
+	    sprintf(t, "rcvdfrom %s@localhost (fake: %s)", s, h->h_lines->t_pname);
+	  } else
+	    sprintf(t, "rcvdfrom %s@localhost", s);
+
+	  h = makeHeader(spt_eheaders, t, 8);
+	  h->h_next = e->e_eHeaders;
+	  e->e_eHeaders = h;
+
+	  h->h_lines = makeToken(t+9, strlen(t+9));
+	  h->h_lines->t_type = Line;
+	  h->h_contents = hdr_scanparse(e, h, 0, 0);
+	  h->h_stamp = hdr_type(h);
+
+	  smtprelay = t+9;
+	}
+
+	if (deferuid)
+	  return PERR_DEFERRED;
+
 	dprintf("Parse envelope and message header\n");
 	e->e_messageid = NULL;
 	perr = 0;
@@ -1159,6 +1210,10 @@ sequencer(e, file)
 			}
 		}
 	}
+
+	if (deferuid)
+	  return PERR_DEFERRED;
+
 	dprintf("Determine if message is a Resent-* type thing\n");
 	e->e_resent = 0;
 	for (h = e->e_headers; h != NULL; h = h->h_next)
@@ -1168,9 +1223,6 @@ sequencer(e, file)
 		}
 	dprintf("It is%s...\n", e->e_resent ? "" : "n't");
 
-	dprintf("Sender authentication\n");
-	e->e_trusted = isgoodguy(e->e_statbuf.st_uid);
-	dprintf("Sender is%s trusted\n", e->e_trusted ? "" : "n't");
 	dprintf("Generate an error message if an error occurred in parsing\n");
 	for (h = e->e_eHeaders; h != NULL; h = h->h_next)
 		if (h->h_stamp == BadHeader)
@@ -1251,6 +1303,9 @@ sequencer(e, file)
 		}
 	}
 
+	if (deferuid)
+	  return PERR_DEFERRED;
+
 	if (h == NULL) {
 		dprintf("A sender was NOT specified in the envelope\n");
 		for (h = e->e_headers; h != NULL; h = h->h_next)
@@ -1442,6 +1497,9 @@ sequencer(e, file)
 	if (QATTRIBUTES(e->e_from_trusted) == NULL)
 		QATTRIBUTES(e->e_from_trusted) =QATTRIBUTES(e->e_from_resolved);
 
+	if (deferuid)
+	  return PERR_DEFERRED;
+
 	dprintf("Recipient determination\n");
 	FindEnvelope(eTo);
 	if (h == NULL) {
@@ -1634,6 +1692,8 @@ sequencer(e, file)
 			}
 			/* freecell(l) */
 		}
+		if (deferuid)
+			return PERR_DEFERRED;
 	}
 
 	dprintf("Crossbar applied to all (sender,routed-address) pairs\n");
@@ -1753,11 +1813,14 @@ sequencer(e, file)
 		}
 	}
 
+	if (deferuid)
+		return PERR_DEFERRED;
+
 	isSenderAddr = isRecpntAddr = 0;
 	dprintf("Make sure Date, From, To, are in the header\n");
 	FindHeader("date",e->e_resent);
 	if (h == NULL)
-	  InsertHeader(h, mkDate(e->e_resent, e->e_statbuf.st_mtime));
+		InsertHeader(h, mkDate(e->e_resent, e->e_statbuf.st_mtime));
 
 	dprintf("Rewrite message headers\n");
 	for (rwp = rwhead; rwp != NULL; rwp = rwp->next) {
@@ -1775,6 +1838,9 @@ sequencer(e, file)
 		*hp = NULL;
 	}
  
+	if (deferuid)
+	  return PERR_DEFERRED;
+
 	if (rwhead == NULL)
 	  return PERR_NORECIPIENTS;
 
@@ -1837,9 +1903,11 @@ sequencer(e, file)
 	if (notaryret != NULL)
 		fprintf(ofp, "%c%c%s\n",
 			_CF_DSNRETMODE, _CFTAG_NORMAL, notaryret);
-	if (e->e_messageid != NULL)
+	if (e->e_messageid != NULL) {
 		fprintf(ofp, "%c%c%s\n",
 			_CF_LOGIDENT, _CFTAG_NORMAL, e->e_messageid);
+		msgidstr = e->e_messageid;
+	}
 	/* else { we don't want to log anything } */
 	if (vfp != NULL) {
 	  if (envid != NULL)
@@ -1953,7 +2021,7 @@ sequencer(e, file)
 			}
 
 			fprintf(ofp, "%c%c", _CF_SENDER, _CFTAG_NORMAL);
-			prctladdr(nsp->info, ofp, _CF_SENDER, "sender");
+			fromaddr = prctladdr(nsp->info, ofp, _CF_SENDER, "sender");
 			putc('\n', ofp);
 			if (vfp != NULL) {
 				fprintf(vfp, "%c%c",
@@ -1975,6 +2043,7 @@ sequencer(e, file)
 				prctladdr(rcp->info, ofp,
 					  _CF_RECIPIENT, "recipient");
 				putc('\n', ofp);
+				++nrcpts;
 				/* DSN data output ! */
 				prdsndata(rcp->info, ofp,
 					  _CF_RCPTNOTARY, "recipient");
@@ -2081,6 +2150,9 @@ sequencer(e, file)
 		return PERR_CTRLFILE;
 	}
 
+	rtsyslog(e->e_statbuf.st_mtime, path, fromaddr, smtprelay,
+		 e->e_statbuf.st_size, nrcpts, msgidstr);
+
 #ifndef	USE_ALLOCA
 	free(ofpname);
 	free(qpath);
@@ -2091,7 +2163,7 @@ sequencer(e, file)
 	return PERR_OK;
 }
 
-static void
+static char *
 prctladdr(info, fp, cfflag, comment)
 	struct conscell *info;
 	FILE *fp;
@@ -2100,14 +2172,16 @@ prctladdr(info, fp, cfflag, comment)
 {
 	int i = 0;
 	register struct conscell *l, *x;
+	char *user = "?user?";
 
 	for (l = car(info); l != NULL; l = cdr(l)) {
 		++i;
 		if (STRING(l)) {
-			if (cdr(l) == NULL
-			    && (x = v_find(l->string)) != NULL
-			    && (x = cdr(x)) != NULL
-			    && LIST(x)) {
+			if (cdr(l) == NULL /* No next == this is the last */
+			    && (x = v_find(l->string)) != NULL /* can find ? */
+			    && (x = cdr(x)) != NULL /* found, ... */
+			    && LIST(x)) {	    /* ... and it is a list */
+				/* Find the 'privilege' item */
 				for (x = car(x); x != NULL; x = cddr(x)) {
 					if (STRING(x)
 					    && strcmp((char *)x->string,
@@ -2122,14 +2196,31 @@ prctladdr(info, fp, cfflag, comment)
 			if (x != NULL) {
 				if (x->string == NULL || *x->string == '\0')
 					putc('-', fp);
-				else
-					fprintf(fp, "%s", x->string);
+				else {
+				  char *s = strchr(x->string,' ');
+				  if (!s) s = strchr(x->string,'\t');
+				  if (s && x->string[0] != '"') {
+				    s = x->string;
+				    putc('"',fp);
+				    while (*s) {
+				      if (*s == '"' || *s == '\\')
+					putc('\\',fp);
+				      putc(*s,fp);
+				      ++s;
+				    }
+				    putc('"',fp);
+				  } else
+				    fprintf(fp, "%s", x->string);
+				}
+				if (i == 3 && x->string != NULL)
+				  user = x->string;
 			}
 			if (cdr(l))
 				putc(' ', fp);
 		} else
 			fprintf(stderr, "Malformed %s\n", comment);
 	}
+	return user;
 }
 
 static void
