@@ -20,7 +20,7 @@
 #include <fcntl.h>
 #include <sys/file.h>
 #include "mail.h"
-#include "syslog.h"
+#include "zsyslog.h"
 #include "interpret.h"
 #include "splay.h"
 
@@ -66,6 +66,7 @@ int	mustexit = 0;
 int	canexit = 0;
 int	router_id = 0;
 int	deferit;
+int	deferuid;
 int	origoptind;
 int	savefile = 0;
 char	*zshopts = "-O";
@@ -280,7 +281,7 @@ main(argc, argv)
 		}
 		else
 		  router_id = getpid();
-		openlog("router", LOG_PID, LOG_MAIL);
+		zopenlog("router", LOG_PID, LOG_MAIL);
 	}
 	if (c < argc) {
 	  savefile = 1;
@@ -455,6 +456,7 @@ uidpwnam(uid)
 			   its nature for this data! */
 			sprintf(buf, "uid#%d", uid);
 			cp = (u_char *)strsave(buf);
+			deferuid = 1;
 		} else {
 			memtypes oval = stickymem;
 			stickymem = MEM_MALLOC;
@@ -561,6 +563,7 @@ logit(file, id, from, to)
 	char *file, *id, *from, *to;
 {
 	int flen, baselen;
+#if 0
 	char c;
 
 	if (id == NULL)
@@ -572,10 +575,8 @@ logit(file, id, from, to)
 		c = *(from+MAXSAFESIZE-baselen);
 		*(from+MAXSAFESIZE-baselen) = '\0';
 		printf("%s: file: %s %s...\n", id, file, from);
-#ifdef	LOG_INFO
 		if (!nosyslog)
-		  syslog(LOG_INFO, "%s: file: %s %s...", id, file, from);
-#endif	/* LOG_INFO */
+		  zsyslog((LOG_INFO, "%s: file: %s %s...", id, file, from));
 		from += MAXSAFESIZE-baselen;
 		*from = c;
 		*--from = '.';
@@ -590,14 +591,12 @@ logit(file, id, from, to)
 			printf("%s: file: %s %s =>%s\n", id, file, from, to);
 		else
 			printf("%s: file: %s %s\n", id, file, to);
-#ifdef	LOG_INFO
 		if (!nosyslog)
 		  if (flen > 0)
-		    syslog(LOG_INFO, "%s: file: %s %s =>%s",
-			   id, file, from, to);
+		    zsyslog((LOG_INFO, "%s: file: %s %s =>%s",
+			     id, file, from, to));
 		  else
-		    syslog(LOG_INFO, "%s: file: %s %s", id, file, to);
-#endif	/* LOG_INFO */
+		    zsyslog((LOG_INFO, "%s: file: %s %s", id, file, to));
 		to += MAXSAFESIZE-baselen-flen;
 		*to = c;
 		*--to = '.';
@@ -606,12 +605,31 @@ logit(file, id, from, to)
 		flen = 0;
 	}
 	if (flen > 0) {
-		printf("%s: file: %s %s =>%s\n", id, file, from, to);
-#ifdef	LOG_INFO
-		if (!nosyslog)
-		  syslog(LOG_INFO, "%s: file: %s %s =>%s", id, file, from, to);
-#endif	/* LOG_INFO */
+	  printf("%s: file: %s %s =>%s\n", id, file, from, to);
+	  if (!nosyslog)
+	    zsyslog((LOG_INFO, "%s: file: %s %s =>%s", id, file, from, to));
 	}
+#else
+	if (id == NULL)
+		id = file;
+	baselen = strlen(file) + strlen(id) + 4;
+	printf("%.200s: file: %.150s %.250s...\n", id, file, from);
+	if (!nosyslog)
+	  zsyslog((LOG_INFO, "%.200s: file: %.150s %.250s...",
+		   id, file, from));
+	flen = strlen(from);
+	if (flen > 0)
+	  printf("%.200s: file: %.150s %.200s => %.200s\n",
+		 id, file, from, to);
+	else
+	  printf("%.200s: file: %.150s %.250s\n", id, file, to);
+	if (!nosyslog)
+	  if (flen > 0)
+	    zsyslog((LOG_INFO, "%.200s: file: %.150s %.200s => %.200s",
+		     id, file, from, to));
+	  else
+	    zsyslog((LOG_INFO, "%.200s: file: %.150s %.200s", id, file, to));
+#endif
 }
 
 char *
