@@ -10,9 +10,6 @@
 
 struct conscell **return_valuep = 0;
 struct conscell *s_value = 0;
-int svstop = -1;
-#define SVSTOPMAX 5 /* Is this too low ? */
-struct conscell *svstack[SVSTOPMAX] = { 0 };
 
 extern int l_apply __((u_char *fname, struct conscell *l));
 int
@@ -21,17 +18,15 @@ l_apply(fname, l)
 	struct conscell *l;
 {
 	int retval;
+	struct conscell *retvp = NULL;
+	struct conscell **oretvp = return_valuep;
+
+	return_valuep = &retvp;
 
-	return_valuep = &svstack[++svstop];
-	if (svstop >= SVSTOPMAX || svstop < 0) {
-	  fprintf(stderr,"l_apply('%s',*l) ran out of svstack[]! (svstop=%d)",
-		  fname,svstop);
-	  abort(); /* Well, we analyze the core if this ever happens.. */
-	}
-	svstack[svstop] = NULL;
 	retval = lapply((char *)fname, l);
-	s_value = svstack[svstop];
-	return_valuep = --svstop < 0 ? NULL : &svstack[svstop];
+	s_value = retvp;
+
+	return_valuep = oretvp;
 	return retval;
 }
 
@@ -42,17 +37,14 @@ s_apply(argc, argv)
 	char *argv[];
 {
 	int retval;
+	struct conscell *retvp = NULL;
+	struct conscell **oretvp = return_valuep;
+
+	return_valuep = &retvp;
 
-	return_valuep = &svstack[++svstop];
-	if (svstop >= SVSTOPMAX || svstop < 0) {
-	  fprintf(stderr,"s_apply() ran out of svstack[]! (svstop=%d)",
-		  svstop);
-	  abort(); /* Well, we analyze the core if this ever happens.. */
-	}
-	svstack[svstop] = NULL;
 	retval = apply(argc, argv);
-	s_value = svstack[svstop];
-	return_valuep = --svstop < 0 ? NULL : &svstack[svstop];
+	s_value = retvp;
+	return_valuep = oretvp;
 	return retval;
 }
 
@@ -357,16 +349,13 @@ static char gsbuf[30];
 /*
  *  newattribute_2()
  */
-char *newattribute_2(oattr,nam,val)
-struct conscell *oattr;
-char *nam, *val;
+char *newattribute_2(onam,nam,val)
+char *onam, *nam, *val;
 {
 	struct conscell *l, *lc, *tmp, **pl;
 	struct conscell	*l1;
 
-	if (!(LIST(oattr) && STRING(car(oattr))))
-	  return NULL;
-	l1 = v_find(car(oattr)->string);
+	l1 = v_find(onam);
 	if (!l1)
 	  return NULL;
 	l = copycell(cdr(l1));
