@@ -977,7 +977,10 @@ report(fp)
 	  if (onlyuser)
 	    printf("No user messages found\n");
 	  else
-	    printf("Transport queue is empty -- or scheduler uses -Q -mode\n");
+	    if (schedq == 0)
+	      printf("Transport queue is empty -- or scheduler uses -Q -mode\n");
+	    else
+	      printf("Transport queue is empty\n");
 	}
 }
 
