@@ -15,7 +15,7 @@
 #include <fcntl.h>
 #include "mail.h"
 #include "scheduler.h"
-#include "syslog.h"
+#include "zsyslog.h"
 #include "ta.h"
 
 #include "prototypes.h"
@@ -41,11 +41,12 @@ extern int never_full_content; /* at conf.c */
  */
 
 struct not {
-	char *not;
-	char *orcpt;
-	char *notify;
-	int   notifyflgs;
-	char *rcpntp;
+	char  *not;
+	char  *orcpt;
+	char  *notify;
+	int    notifyflgs;
+	char  *rcpntp;
+	time_t tstamp;
 };
 
 static void
@@ -105,7 +106,7 @@ scnotaryreport(errfp,notary,haserrsp)
 	}
 
 	if (*rcpt == '\003' /* XX: MAGIC! */) {
-	  /* Tough, internal expiry didn't know our target address!
+	  /* Tough, scheduler internal expiry didn't know our target address!
 	     Lets scan it from  rcpntp .. We can mush the string pointed
 	     by the rcpntp.. */
 	  char *s = notary->rcpntp;
@@ -143,6 +144,8 @@ scnotaryreport(errfp,notary,haserrsp)
 	fprintf(errfp, "Diagnostic-Code: %s\n", diagnostic);
 	if (wtt && wtt[0] != 0)
 	  fprintf(errfp, "Remote-MTA: %s\n", wtt);
+	if (notary->tstamp != 0)
+	  fprintf(errfp, "Last-Attempt-Date: %s", rfc822date(&notary->tstamp));
 	fprintf(errfp, "\n");
 	action[-1] = '\001';
 	if (status)
@@ -183,10 +186,10 @@ msgerror(vp, offset, message)
 	  return;
 	}
 	vp->cfp->haderror = 1;
-	fprintf(fp, "%c%c%ld:%ld:%ld\t%s\t%s\n",
+	fprintf(fp, "%c%c%ld:%ld:%ld::%ld\t%s\t%s\n",
 		_CF_DIAGNOSTIC, _CFTAG_NORMAL, offset,
 		vp->headeroffset, vp->drptoffset,
-		notary, message);
+		time(NULL), notary, message);
 	fflush(fp);
 #ifdef HAVE_FSYNC
 	fsync(FILENO(fp));
@@ -330,6 +333,7 @@ reporterrs(cfpi)
 {
 	int i, n, wroteheader, byteidx, headeridx = -1, drptidx, fd;
 	long *lp;
+	time_t tstamp;
 	char *midbuf, *cp, *s, *eaddr;
 	char *deliveryform;
 	FILE *errfp, *fp;
@@ -345,6 +349,7 @@ reporterrs(cfpi)
 	int has_errors = 0;
 	int lastoffset;
 	char path[MAXPATHLEN], mpath[MAXPATHLEN];
+	int mypid;
 
 	if (cfpi->haderror == 0)
 		return;
@@ -384,6 +389,7 @@ reporterrs(cfpi)
 	  free_cfp_memory(cfp);
 	  return;
 	}
+	mypid = getpid();
 	if (cfp->mid) free(cfp->mid);
 	cfp->mid = midbuf; /* This is the original one! */
 	wroteheader = 0;
@@ -395,7 +401,7 @@ reporterrs(cfpi)
 	    continue;
 
 	  /* Line fmt:
-	     <TAGS> offset ':' headeroffset ':' drptidx : dnsrcpnt <TAB> NOTARY-DATA <TAB> MESSAGE <NL> */
+	     <TAGS> offset ':' headeroffset ':' drptidx ':' dnsrcpnt ':' timestamp  <TAB> NOTARY-DATA <TAB> MESSAGE <NL> */
 
 	  cp = cfp->contents + *lp + 2;
 
@@ -429,6 +435,13 @@ reporterrs(cfpi)
 	    while (isascii(*cp) && (isdigit(*cp) || *cp == '-'))
 	      ++cp;
 	  }
+	  tstamp = 0;
+	  if (*cp == ':') {
+	    ++cp;
+	    tstamp = atol(cp);
+	    while (isascii(*cp) && (isdigit(*cp) || *cp == '-'))
+	      ++cp;
+	  }
 	  /* If ever need to add more integer offsets, add them
 	     here with a colon prefix... */
 	  notary = NULL;
@@ -440,7 +453,7 @@ reporterrs(cfpi)
 	  }
 	  rcpntpointer = cfp->contents + byteidx + 2 + _CFTAG_RCPTPIDSIZE;
 	  if (do_syslog)
-	    syslog(LOG_INFO, "%s: <%s>: %s", cfp->mid, rcpntpointer, cp);
+	    zsyslog((LOG_INFO, "%s: <%s>: %s", cfp->mid, rcpntpointer, cp));
 
 	  if (notary != NULL && *notary != 0) {
 	    if (!notaries) {
@@ -457,6 +470,7 @@ reporterrs(cfpi)
 	    notaries[notarycnt].notify = NULL;
 	    notaries[notarycnt].notifyflgs = 0;
 	    notaries[notarycnt].rcpntp = rcpntpointer;
+	    notaries[notarycnt].tstamp = tstamp;
 	    if (drptidx > 0) {
 	      char *d = cfp->contents + drptidx;
 	      while (*d) {
@@ -538,7 +552,7 @@ reporterrs(cfpi)
 	    putc('\n', errfp);
 	  } else
 	    fprintf(errfp, "%s\n", cp);
-	  lockaddr(cfp->fd, NULL, *lp + 1, _CFTAG_NORMAL, _CFTAG_OK, mpath, "diagmsg");
+	  lockaddr(cfp->fd, NULL, *lp + 1, _CFTAG_NORMAL, _CFTAG_OK, mpath, "diagmsg", mypid);
 	}
 	/* End of all diagnostics message lines */
 
@@ -594,7 +608,9 @@ reporterrs(cfpi)
 	  if (cfp->msgbodyoffset > 0 && headeridx > 0 ) {
 	    /* We have knowledge about the headers of errored email,
 	       use those headers on output ! */
-	    fputs(cfp->contents+headeridx, errfp);
+	    if (strncmp(cfp->contents + headeridx, "m\n", 2) == 0)
+	      headeridx += 2;
+	    fputs(cfp->contents + headeridx, errfp);
 	    putc('\n', errfp); /* Newline in between headers and the body.. */
 	    fseek(fp, (off_t)(cfp->msgbodyoffset), SEEK_SET);
 	  } else {
