@@ -242,6 +242,7 @@ readconfig(file)
 	  if (verbose)
 	    printf("read '%s' %d\n",  line, n);
 	  if (n == 1) {
+	    /* Selector entry */
 	    if (ce != NULL)
 	      celink(ce, &head, &tail);
 	    ce = (struct config_entry *)emalloc(sizeof (struct config_entry));
@@ -255,8 +256,8 @@ readconfig(file)
 	      ce->channel = strsave(line);
 	      ce->host    = strsave("*");
 	    }
-	    if (line[0]=='*' && (strcmp(line,"*/*")==0 ||
-				 strcmp(line,"*")==0)) {
+	    if (line[0]=='*' && (strcmp(line,"*/*") == 0 ||
+				 line[1] == 0)) {
 	      /* The default entry.. */
 	      if (default_entry != NULL) {
 		if (ce->channel) free (ce->channel);
