@@ -44,7 +44,7 @@
 #endif
 
 #include "prototypes.h"
-#include "syslog.h"
+#include "zsyslog.h"
 
 #ifndef	MAXNAMLEN /* POSIX.1 ... */
 #define MAXNAMLEN NAME_MAX
@@ -533,7 +533,7 @@ main(argc, argv)
 
 	for (i = 0; i < SIZE_L; ++i)
 	  spt_mesh[i] = sp_init();
-	openlog("scheduler", LOG_PID, LOG_MAIL);
+	zopenlog("scheduler", LOG_PID, LOG_MAIL);
 	if (optind < argc) {
 	  /* process the specified control files only */
 	  for (; optind < argc; ++optind) {
@@ -1324,7 +1324,7 @@ static struct ctlfile *vtxprep(cfp, file)
 	struct vertex *vp, *pvp, **pvpp, *head;
 	struct stat stbuf;
 	struct offsort *offarr;
-	int offspc;
+	int offspc, mypid;
 	long ino;
 	int prevrcpt = -1;
 	int is_turnme = 0;
@@ -1342,6 +1342,7 @@ static struct ctlfile *vtxprep(cfp, file)
 	offspc = 16;
 	offarr = (struct offsort *)emalloc(offspc * sizeof(struct offsort));
 
+	mypid = getpid();
 	opcnt = 0;
 	svn = 0;
 	vtxprep_skip = 0;
@@ -1386,7 +1387,7 @@ static struct ctlfile *vtxprep(cfp, file)
 	    *cp = _CFTAG_NORMAL; /* unlock it */
 	    lockaddr(cfp->fd, NULL, (long) (cp - cfp->contents),
 		     _CFTAG_LOCK, _CFTAG_NORMAL, cfp->mid,
-		     cp+_CFTAG_RCPTPIDSIZE);
+		     cp+_CFTAG_RCPTPIDSIZE, mypid);
 	  }
 	  /* Calculate summary info */
 	  if (cp[-1] == _CF_RECIPIENT) {
