@@ -60,7 +60,7 @@ extern struct sptree *spt_mesh[SIZE_L];
 
 struct ctlfile {
 	int	fd;		/* a file descriptor pointing at the file    */
-	FILE	*vfp;		/* a FILE * for verbose logging for mail -v  */
+	char	*vfpfn;		/* a filename for verbose logging of mail    */
 	uid_t	uid;		/* the owner of the control file (= msg file)*/
 	time_t	ctime;		/* when the original file arrived	     */
 	time_t	envctime;	/* when the transport file was created	     */
@@ -168,7 +168,6 @@ struct vertex {
 #define NOT_DELAY   002
 #define NOT_SUCCESS 004
 #define NOT_FAILURE 010
-	char		*dnsrecipient;	/*				     */
 	int		ce_pending;	/* pending on what ?		     */
 	time_t		ce_expiry;	/* when this vertex expires ?        */
 	struct procinfo *proc;		/* current TA process description    */
