@@ -596,9 +596,7 @@ static int vtx_ctime_cmp(ap, bp)
 	if ((*a)->cfp->ctime < (*b)->cfp->ctime)
 	  return -1;
 	else if ((*a)->cfp->ctime == (*b)->cfp->ctime)
-	  /* If same age, order in memory defines the result,
-	     and thus stabilizing the sort result.            */
-	  return (*a)->cfp - (*b)->cfp;
+	  return 0;
 	else
 	  return 1;
 }
