@@ -92,22 +92,24 @@ struct procinfo *proc;
 	} else {
 	  strcpy(proc->cmdbuf,"#idle\n");
 	  len = strlen(proc->cmdbuf);
+	  /* Count this feed as one of normal inputs.
+	     At least we WILL get a "#hungry" message for this */
+	  proc->overfed += 1;
 	}
 	rc = write(proc->tofd, proc->cmdbuf, len);
-	if (rc != len) {
-	  if (rc < 0 && (errno != EAGAIN && errno != EINTR &&
-			 errno != EWOULDBLOCK)) {
-	    /* Some real failure :-( */
-	    pipes_shutdown_child(proc->tofd);
-	    proc->tofd = -1;
-	    if (proc->vertex)
-	      proc->vertex->proc = NULL;
-	    if (proc->thread)
-	      proc->thread->proc = NULL;
-	    proc->thread         = NULL;
-	    proc->cmdlen = 0;
-	    return;
-	  }
+	if (rc != len && rc < 0 &&
+	    (errno != EAGAIN && errno != EINTR &&
+	     errno != EWOULDBLOCK)) {
+	  /* Some real failure :-( */
+	  pipes_shutdown_child(proc->tofd);
+	  proc->tofd = -1;
+	  if (proc->vertex)
+	    proc->vertex->proc = NULL;
+	  if (proc->thread)
+	    proc->thread->proc = NULL;
+	  proc->thread         = NULL;
+	  proc->cmdlen = 0;
+	  return;
 	}
 	proc->cmdlen = 0;
 }
@@ -613,11 +615,11 @@ typedef long	fd_mask;
 typedef	struct fd_set { fd_mask	fds_bits[1]; } fd_set;
 #endif	/* notdef */
 
-#ifndef	FD_SET
-#define	FD_SET(n, p)	((p)->fds_bits[0] |= (1 << (n)))
-#define	FD_CLR(n, p)	((p)->fds_bits[0] &= ~(1 << (n)))
-#define	FD_ISSET(n, p)	((p)->fds_bits[0] & (1 << (n)))
-#define FD_ZERO(p)	bzero((char *)(p), sizeof(*(p)))
+#ifndef	_Z_FD_SET
+#define	_Z_FD_SET(n, p)   ((p)->fds_bits[0] |= (1 << (n)))
+#define	_Z_FD_CLR(n, p)   ((p)->fds_bits[0] &= ~(1 << (n)))
+#define	_Z_FD_ISSET(n, p) ((p)->fds_bits[0] & (1 << (n)))
+#define _Z_FD_ZERO(p)	  memset((char *)(p), 0, sizeof(*(p)))
 #endif	/* !FD_SET */
 #endif	/* !NFDBITS */
 
