@@ -11,9 +11,9 @@
 #include "hostenv.h"
 #include <stdio.h>
 #include <ctype.h>
-#include <syslog.h>
 #include <sys/param.h>
 #include <sys/stat.h>
+#include "zsyslog.h"
 #include "mail.h"
 #include "scheduler.h"
 
@@ -241,7 +241,7 @@ unctlfile(cfp, no_unlink)
 	  reporterrs(cfp);
 
 	  if (do_syslog)
-	    syslog(LOG_INFO, "%s: done", cfp->mid);
+	    zsyslog((LOG_INFO, "%s: done", cfp->mid));
 
 	  eunlink(path);
 	  if (verbose)
@@ -303,7 +303,7 @@ void unvertex(vp, justfree, ok)
 	}
 
 	if (vp->proc && vp->proc->vertex == vp) {
-	  vp->proc->fed = 1;     /* Mark it fed just in case.. */
+	  vp->proc->fed     = 1; /* Mark it fed just in case.. */
 	  vp->proc->overfed = 0; /* .. and clear this .. */
 	  /* Pick next, but don't feed it (yet)! */
 	  pick_next_vertex(vp->proc, ok, justfree);
@@ -468,7 +468,7 @@ deletemsg(msgid, curcfp)
 	 */
 
 	if (do_syslog)
-	  syslog(LOG_INFO, "%s: obsoleted by %s", cfp->mid, curcfp->mid);
+	  zsyslog((LOG_INFO, "%s: obsoleted by %s", cfp->mid, curcfp->mid));
 
 	/*
 	 * unvertex() will do unctlfile() on the last vertex, hence
@@ -643,8 +643,8 @@ expire(vp, index)
 	  sprintf(buf,"%s\001%s\001%s\001%s",
 		  "\003", /* XX: recipient address! XX: MAGIC INFO! */
 		  "failed",
-		  "4.0.0 (unspecified timeout failure)",
-		  "smtp; 400 (Expired after ");
+		  "5.4.7 (unspecified timeout failure)",
+		  "smtp; 500 (Expired after ");
 	  saytime((u_long)(vp->ce_expiry - vp->cfp->ctime), buf, 0);
 	  strcat(buf,")\001");
 	  vp->notary = strsave(buf);
