@@ -13,7 +13,7 @@
 #include <fcntl.h>
 #include <pwd.h>
 #include <time.h>
-#include <syslog.h>
+#include "zsyslog.h"
 /* #include <tzfile.h> */  /* Not needed ? */
 #include <errno.h>
 #include <sysexits.h>
@@ -499,9 +499,9 @@ findme:			for (cur = names; !tome && cur; cur = cur->next)
 		exit(EX_OK);
 	}
 	if (!*from) {
-		openlog("vacation", LOG_PID, LOG_MAIL);
-		syslog(LOG_NOTICE, "vacation: no initial \"From\" line.\n");
-		exit(EX_USAGE+105);
+	  zopenlog("vacation", LOG_PID, LOG_MAIL);
+	  zsyslog((LOG_NOTICE, "vacation: no initial \"From\" line.\n"));
+	  exit(EX_USAGE+105);
 	}
 }
 
