@@ -13,8 +13,8 @@
 #include <sys/param.h>
 #include <sys/stat.h>
 #include "mail.h"
-#include "syslog.h"
 #include "zmsignal.h"
+#include "zsyslog.h"
 #include "ta.h"
 
 
@@ -106,7 +106,7 @@ main(argc, argv)
 	}
 
 	/* We need this latter on .. */
-	openlog("errormail", LOG_PID, LOG_MAIL);
+	zopenlog("errormail", LOG_PID, LOG_MAIL);
 
 	while (!getout) {
 	  char *s, *host;
@@ -132,7 +132,7 @@ main(argc, argv)
 	  if (host != NULL)
 	    *host++ = 0;
 
-	  dp = ctlopen(msgfilename, channel, host, &getout, ctlsticky, NULL);
+	  dp = ctlopen(msgfilename, channel, host, &getout, ctlsticky, NULL, NULL, NULL);
 	  if (dp != NULL) {
 	    process(dp);
 	    ctlclose(dp);
