@@ -15,7 +15,7 @@
 #include <sys/stat.h>
 #include "zmsignal.h"
 #include "malloc.h"
-#include "syslog.h"
+#include "zsyslog.h"
 
 #ifdef	HAVE_RESOLVER
 #include "netdb.h"
@@ -145,7 +145,7 @@ main(argc, argv)
 	int argc;
 	char *argv[];
 {
-	char *channel, file[MAXPATHLEN+1];
+	char *channel, *host, file[MAXPATHLEN+1];
 	int errflg, c, i;
 	struct ctldesc *dp;
 	RETSIGTYPE (*oldsig)();
@@ -196,7 +196,7 @@ main(argc, argv)
 	}
 
 	/* We need this latter on .. */
-	openlog("hold", LOG_PID, LOG_MAIL);
+	zopenlog("hold", LOG_PID, LOG_MAIL);
 
 	while (!getout) {
 	  char *s;
@@ -216,12 +216,14 @@ main(argc, argv)
 	    break;
 
 	  s = strchr(file,'\t');
+	  host = NULL;
 	  if (s != NULL) {
 	    /* Ignore the host part */
-	    *s = 0;
+	    *s++ = 0;
+	    host = s;
 	  }
 
-	  dp = ctlopen(file, channel, (char *)NULL, &getout, NULL, NULL);
+	  dp = ctlopen(file, channel, host, &getout, NULL, NULL, NULL, NULL);
 	  if (dp != NULL) {
 	    process(dp);
 	    ctlclose(dp);
@@ -513,6 +515,7 @@ struct qtypes {
 } qt[] = {
 	{	"cname",	1		},
 	{	"a",		1		},
+	{	"aaaa",		1		},
 	{	"ptr",		2		},
 	{	NULL,		NULL		}
 };
