@@ -195,11 +195,13 @@ ctladdr(cp)
 }
 
 struct ctldesc *
-ctlopen(file, channel, host, exitflagp, selectaddr, matchrouter)
+ctlopen(file, channel, host, exitflagp, selectaddr, saparam, matchrouter, mrparam)
 	char *file, *channel, *host;
 	int *exitflagp;
 	int (*selectaddr)();
+	void *saparam;
 	int (*matchrouter)();
+	void *mrparam;
 {
 	register char *s;
 	char *mfpath;
@@ -213,11 +215,12 @@ ctlopen(file, channel, host, exitflagp, selectaddr, matchrouter)
 	int headers_spc = 0;
 	int largest_headersize = 80; /* Some magic minimum.. */
 	char dirprefix[8];
+	int mypid = getpid();
 
 	static struct ctldesc d; /* ONLY ONE OPEN AT THE TIME! */
 
 	if (selectaddr == ctlsticky)
-	  ctlsticky(NULL,NULL); /* Reset the internal state.. */
+	  ctlsticky(NULL,NULL,NULL); /* Reset the internal state.. */
 
 	memset(&d,0,sizeof(d));
 	if (*file >= 'A') {
@@ -267,6 +270,9 @@ ctlopen(file, channel, host, exitflagp, selectaddr, matchrouter)
 	  warning("Out of virtual memory!", (char *)NULL);
 	  exit(EX_SOFTWARE);
 	}
+
+	fcntl(d.ctlfd, F_SETFD, 1); /* Close-on-exec */
+
 #ifdef HAVE_MMAP
 #ifndef MAP_VARIABLE
 # define MAP_VARIABLE 0
@@ -377,14 +383,14 @@ ctlopen(file, channel, host, exitflagp, selectaddr, matchrouter)
 		 && strcmp(channel, ap->channel) != 0)
 #if 1
 		|| (ap->routermxes != NULL && matchrouter != NULL
-		    && !(*matchrouter)(host, ap))
+		    && !(*matchrouter)(host, ap, mrparam))
 #endif
 		|| (ap->routermxes == NULL && selectaddr != NULL
-		    && !(*selectaddr)(host, ap->host))
+		    && !(*selectaddr)(host, ap->host, saparam))
 		|| (ap->routermxes == NULL && selectaddr == NULL
 		    && host != NULL && cistrcmp(host,ap->host) !=0)
 		|| !lockaddr(d.ctlfd, d.ctlmap, d.offset[i]+1,
-			     _CFTAG_NORMAL, _CFTAG_LOCK, file, host)) {
+			     _CFTAG_NORMAL, _CFTAG_LOCK, file, host, mypid)) {
 	      if (ap->routermxes)
 		free((char *)ap->routermxes);
 	      ap->routermxes = NULL;
@@ -395,7 +401,7 @@ ctlopen(file, channel, host, exitflagp, selectaddr, matchrouter)
 	    rp = (struct rcpt *)emalloc(sizeof (struct rcpt));
 	    if (rp == NULL) {
 	      lockaddr(d.ctlfd, d.ctlmap, d.offset[i]+1,
-		       _CFTAG_LOCK, _CFTAG_DEFER, file, host);
+		       _CFTAG_LOCK, _CFTAG_DEFER, file, host, mypid);
 	      warning("Out of virtual memory!", (char *)NULL);
 	      *exitflagp = 1;
 	      break;
@@ -523,7 +529,7 @@ ctlopen(file, channel, host, exitflagp, selectaddr, matchrouter)
 		   rp = rp->next) {
 		rp->newmsgheader    = &msgheaders   [headers_cnt];
 		rp->newmsgheadercvt = &msgheaderscvt[headers_cnt];
-		rp->headeroffset    = d.offset[i];
+		rp->headeroffset    = d.offset[i] + 2;
 	      }
 
 	      msgheaders   [++headers_cnt] = NULL;
@@ -600,6 +606,9 @@ ctlopen(file, channel, host, exitflagp, selectaddr, matchrouter)
 	  close(d.msgfd);
 	  return NULL;
 	}
+
+	fcntl(d.msgfd, F_SETFD, 1); /* Close-on-exec */
+
 #ifdef	HAVE_MMAP
 	d.let_buffer = (char *)mmap(NULL, stbuf.st_size, PROT_READ,
 				    MAP_FILE|MAP_SHARED|MAP_VARIABLE,
@@ -625,7 +634,8 @@ ctlopen(file, channel, host, exitflagp, selectaddr, matchrouter)
 	d.msgmtime = stbuf.st_mtime;
 
 	/* Estimate the size of the message file when sent out.. */
-	d.msgsizeestimate = stbuf.st_size + largest_headersize;
+	d.msgsizeestimate  = stbuf.st_size - d.msgbodyoffset;
+	d.msgsizeestimate += largest_headersize;
 	/* A nice fudge factor, usually this is enough..                 */
 	/* Add 3% for CRLFs.. -- assume average line length of 35 chars. */
 	d.msgsizeestimate += (3 * d.msgsizeestimate) / 100;
@@ -634,8 +644,9 @@ ctlopen(file, channel, host, exitflagp, selectaddr, matchrouter)
 }
 
 int
-ctlsticky(spec_host, addr_host)
+ctlsticky(spec_host, addr_host, cbparam)
 	char *spec_host, *addr_host;
+	void *cbparam;
 {
 	static char *hostref = NULL;
 
