@@ -82,6 +82,8 @@ char *okstr;
 }
 
 static char *wtthost = NULL; /* NOTARY wtthost: 'While-Talking-To -host' */
+static char *wttip   = NULL;
+
 void notary_setwtt(host)
 char *host;
 {
@@ -92,6 +94,16 @@ char *host;
 	  wtthost = NULL;
 }
 
+void notary_setwttip(ip)
+char *ip;
+{
+	if (wttip) free(wttip);
+	if (ip)
+	  wttip = strdup(ip);
+	else
+	  wttip = NULL;
+}
+
 static int xdelay = 0;
 void notary_setxdelay(xdly)
 int xdly;
@@ -194,7 +206,7 @@ diagnostic(rp, rc, timeout, fmt, va_alist) /* (rp, rc, timeout, "fmtstr", remote
 			*s++ = '%';
 			break;
 		case '\0':
-			--fmt;	/* exit soonest */
+			--fmt;	/* exit asap! */
 			break;
 		}
 	}
@@ -281,14 +293,15 @@ diagnostic(rp, rc, timeout, fmt, va_alist) /* (rp, rc, timeout, "fmtstr", remote
 #else
 	  sbuf = emalloc(len);
 #endif
-	  /* XX: log the diagnostic string to the file */
+
+	  /* Log the diagnostic string to the file */
 #ifndef SPRINTF_CHAR
 	  len = 
 #endif
-	    sprintf(sbuf, "%c%c%d:%d:%d:\t%s\t%s\n",
+	    sprintf(sbuf, "%c%c%ld:%ld:%ld::%ld\t%s\t%s\n",
 		    _CF_DIAGNOSTIC, _CFTAG_NORMAL,
 		    rp->id, rp->headeroffset, rp->drptoffset,
-		    notarybuf, message);
+		    time(NULL), notarybuf, message);
 #ifdef SPRINTF_CHAR
 	  len = strlen(sbuf);
 #endif
@@ -300,6 +313,7 @@ diagnostic(rp, rc, timeout, fmt, va_alist) /* (rp, rc, timeout, "fmtstr", remote
 	    /* UAARGH! -- write failed, must have disk full! */
 	    exit(EX_DATAERR);
 	  }
+	  fsync(rp->desc->ctlfd);
 	  if (oldalarm)		/* Restore it, if it was ticking. */
 	    alarm(oldalarm);
 
@@ -322,11 +336,11 @@ diagnostic(rp, rc, timeout, fmt, va_alist) /* (rp, rc, timeout, "fmtstr", remote
 
 	if (!lockaddr(rp->desc->ctlfd, rp->desc->ctlmap,
 		      rp->lockoffset, _CFTAG_LOCK, mark,
-		      rp->desc->msgfile, "?host?")) {
+		      rp->desc->msgfile, "?host?", getpid())) {
 	  /* something went wrong in unlocking it, concurrency problem? */
 	}
 	rp->lockoffset = 0;	/* mark this recipient unlocked */
 	fflush(stdout);
 
-	tasyslog(rp, xdelay, wtthost, statmsg, message);
+	tasyslog(rp, xdelay, wtthost, wttip, statmsg, message);
 }
