@@ -17,6 +17,7 @@
 #include <sysexits.h>
 #include <sys/param.h>
 #include <sys/stat.h>
+#include <errno.h>
 #include "zmsignal.h"
 #include "malloc.h"
 
@@ -27,6 +28,15 @@
 #endif
 #include <sys/socket.h>
 #include <netinet/in.h>
+#ifdef HAVE_NETINET_IN6_H
+# include <netinet/in6.h>
+#endif
+#ifdef HAVE_NETINET6_IN6_H
+# include <netinet6/in6.h>
+#endif
+#ifdef HAVE_LINUX_IN6_H
+# include <linux/in6.h>
+#endif
 #endif	/* HAVE_RESOLVER */
 
 #include "ta.h"
@@ -38,9 +48,18 @@
 #endif	/* TRY_AGAIN */
 #ifdef	BIND
 #undef NOERROR /* Solaris  <sys/socket.h>  has  NOERROR too.. */
+
 #include <arpa/nameser.h>
 #include <resolv.h>
 
+#ifndef HFIXEDSZ	/* An ancient resolver (arpa/nameser.h) file ? */
+# define HFIXEDSZ 12
+#endif
+#ifndef NETDB_SUCCESS	/* Ancient <netdb.h> ? */
+# define NETDB_SUCCESS   0
+# define NETDB_INTERNAL -1
+#endif
+
 #ifndef	BIND_VER
 #ifdef	GETLONG
 /* 4.7.3 introduced the {GET,PUT}{LONG,SHORT} macros in nameser.h */
@@ -129,15 +148,30 @@ extern char *strchr();
 #define	MAXPACKET	1024
 #endif
 
+#ifndef INADDRSZ
+# define INADDRSZ 4
+#endif
+#ifndef IN6ADDRSZ
+# define IN6ADDRSZ 16
+#endif
+#ifndef AF_INET6
+# define AF_INET6 999 /* If the system does not define this,  we use a value
+			 that nobody has as AF_ value -- I hope.. */
+#endif
+#ifndef INT16SZ
+# define INT16SZ 2
+#endif
+#ifndef INT32SZ
+# define INT32SZ 4
+#endif
+
 typedef union {
     HEADER hdr;
     u_char buf[MAXPACKET];
 } querybuf;
 
-typedef union {
-    int32_t al;
-    char ac;
-} align;
+#define ALIGN      4 /* IPv4 works ok with 32-bit alignment */
+#define ALIGN_AAAA 8 /* IPv6 can use 64-bit machines more efficiently.. */
 
 extern int h_errno;
 extern FILE *verboselog;
@@ -304,30 +338,13 @@ getrrtype(host, ttlp, hbsize, rrtype, cnamelevel, verboselog)
 }
 
 
-/* These are slightly tweaked versions of  gethostbyaddr_r(), and
-   gethostbyname2_r() routines from  BIND 4.9.4 -- "slighly" by adding
+/* These are slightly tweaked versions of  gethostbyaddr(), and
+   gethostbyname2() routines from  BIND 4.9.4 -- "slighly" by adding
    a state block into parameters, and thus removing blind static arrays. */
 
 static int res_hnok(cp)const char *cp;{return 1;}
 static int res_dnok(cp)const char *cp;{return 1;}
 
-#ifndef INADDRSZ
-# define INADDRSZ 4
-#endif
-#ifndef IN6ADDRSZ
-# define IN6ADDRSZ 16
-#endif
-#ifndef AF_INET6
-# define AF_INET6 999 /* If the system does not define this,  we use a value
-			 that nobody has as AF_ value -- I hope.. */
-#endif
-#ifndef INT16SZ
-# define INT16SZ 2
-#endif
-#ifndef INT32SZ
-# define INT32SZ 4
-#endif
-
 static const char AskedForGot[] =
 			  "gethostby*.getanswer_r: asked for \"%s\", got \"%s\"";
 
@@ -364,7 +381,7 @@ map_v4v6_hostent(hp, bpp, lenp)
 	hp->h_addrtype = AF_INET6;
 	hp->h_length = IN6ADDRSZ;
 	for (ap = hp->h_addr_list; *ap; ap++) {
-		int i = sizeof(align) - ((u_long)*bpp % sizeof(align));
+		int i = ALIGN_AAAA - ((u_long)*bpp % ALIGN_AAAA);
 
 		if (*lenp < (i + IN6ADDRSZ)) {
 			/* Out of memory.  Truncate address list here.  XXX */
@@ -598,7 +615,10 @@ getanswer_r(answer, anslen, qname, qtype, result)
 				buflen -= nn;
 			}
 
-			bp += sizeof(align) - ((u_long)bp % sizeof(align));
+			if (type == T_A)
+			  bp += ALIGN      - ((u_long)bp % ALIGN     );
+			else
+			  bp += ALIGN_AAAA - ((u_long)bp % ALIGN_AAAA);
 
 			if (bp + n >= &result->hostbuf[sizeof(result->hostbuf)]) {
 				DPRINTF(("size (%d) too big\n", n));
@@ -655,7 +675,7 @@ getanswer_r(answer, anslen, qname, qtype, result)
 }
 
 struct hostent *
-gethostbyname2_r(name, af, result)
+gethostbyname2_rz(name, af, result)
 	const char *name;
 	int af;
 	struct dnsresult *result;
@@ -689,6 +709,7 @@ gethostbyname2_r(name, af, result)
 	result->host.h_addrtype = af;
 	result->host.h_length = size;
 
+#if 0
 	/*
 	 * if there aren't any dots, it could be a user-level alias.
 	 * this is also done in res_query() since we are not the only
@@ -696,6 +717,7 @@ gethostbyname2_r(name, af, result)
 	 */
 	if (!strchr(name, '.') && (cp = __hostalias(name)))
 		name = cp;
+#endif
 
 	/*
 	 * disallow names consisting only of digits/dots, unless
@@ -746,7 +768,7 @@ gethostbyname2_r(name, af, result)
 }
 
 struct hostent *
-gethostbyaddr_r(addr, len, af, result)
+gethostbyaddr_rz(addr, len, af, result)
 	const char *addr;	/* XXX should have been def'd as u_char! */
 	int len, af;
 	struct dnsresult *result;
@@ -765,7 +787,7 @@ gethostbyaddr_r(addr, len, af, result)
 	char hname2[MAXDNAME+1];
 #endif /*SUNSECURITY*/
 	extern struct hostent *_gethtbyaddr();
-	
+
 	if ((_res.options & RES_INIT) == 0 && res_init() == -1) {
 		h_errno = NETDB_INTERNAL;
 		return (NULL);
@@ -820,7 +842,7 @@ gethostbyaddr_r(addr, len, af, result)
 	}
 	n = res_query(qbuf, C_IN, T_PTR, (u_char *)buf.buf, sizeof buf.buf);
 	if (n < 0) {
-	  DPRINTF(("res_query failed (%d)\n", n));
+		DPRINTF(("res_query failed (%d)\n", n));
 #if 0 /* No fallback to file! */
 		if (errno == ECONNREFUSED)
 			return (_gethtbyaddr(addr, len, af));
