@@ -26,13 +26,14 @@
 #endif	/* L_SET */
 
 int
-lockaddr(fd, map, offset, was, new, file, host)
+lockaddr(fd, map, offset, was, new, file, host, mypid)
 	int	fd;
 	char	*map;
 	long	offset;
 	int	was;
 	int	new;
 	const char *file, *host;
+	const int mypid;
 {
 	char	lockbuf[16];
 	int	newlock = 0;
@@ -89,12 +90,8 @@ lockaddr(fd, map, offset, was, new, file, host)
 #ifdef USE_FCNTLLOCK
 	      /* Using FCNTL region locking */
 #else
-	      static int mypid = -1;
-	      if (mypid < 0)
-		mypid = getpid();
-
 	      /* Mark the lock with client process-id */
-	      sprintf(lockbuf+1,"%*d",_CFTAG_RCPTPIDSIZE,mypid);
+	      sprintf(lockbuf+1, "%*d", _CFTAG_RCPTPIDSIZE, mypid);
 	      if (map)
 		memcpy(map+offset, lockbuf, _CFTAG_RCPTPIDSIZE+1);
 	      else if (write(fd,lockbuf,
@@ -106,7 +103,7 @@ lockaddr(fd, map, offset, was, new, file, host)
 	      /* Using FCNTL region locking */
 #else
 	      /* Clear the lock location */
-	      sprintf(lockbuf+1,"%*s",_CFTAG_RCPTPIDSIZE,"");
+	      sprintf(lockbuf+1,"%*s", _CFTAG_RCPTPIDSIZE, "");
 	      if (map)
 		memcpy(map+offset, lockbuf, _CFTAG_RCPTPIDSIZE+1);
 	      else if (write(fd,lockbuf,
@@ -115,7 +112,7 @@ lockaddr(fd, map, offset, was, new, file, host)
 #endif
 	    } else {
 	      /* Clear the lock location */
-	      sprintf(lockbuf+1,"%*s",_CFTAG_RCPTPIDSIZE,"");
+	      sprintf(lockbuf+1, "%*s", _CFTAG_RCPTPIDSIZE, "");
 	      if (map)
 		memcpy(map+offset, lockbuf, _CFTAG_RCPTPIDSIZE+1);
 	      else if (write(fd,lockbuf,
