@@ -208,6 +208,7 @@ headers_to_mime2(rp,defcharset,verboselog)
 {
 #ifndef USE_NEW_MIME2_CODE
 	char **inhdr;
+	int wasmime2word = 0;
 
 	if (*(rp->newmsgheadercvt) == NULL)
 	  if (!cvtspace_copy(rp))
@@ -245,8 +246,8 @@ if (verboselog) fprintf(verboselog,"8-bit header: '%s'\n",hdr);
 	      /* Copy the head */
 	      q = newbuf;
 	      while (p < s) *q++ = *p++;
-	      strcpy((void*)q,"=?UNKNOWN-8BIT?Q?");
-	      q += 17; /* 17 chars above */
+	      sprintf(q,"=?%s?Q?", defcharset);
+	      q += strlen(q);
 
 	      for ( ; *s && (*s != ' ' && *s != '\t' && *s != ')'); ++s) {
 		if (*s < ' '  || *s > 126  ||
@@ -263,6 +264,8 @@ if(verboselog)fprintf(verboselog,"After processing: '%s'\n",newbuf);
 	      hdr = *inhdr = (char *)newbuf;
 	      newbuf = NULL;
 	      goto qphdr_restart;
+	    } else {
+	      
 	    }
 	  }
 	  if (newbuf) free(newbuf);
