@@ -42,6 +42,7 @@ extern char *strchr();
 #endif
 extern void *emalloc();
 extern void *erealloc();
+extern char *getzenv();
 
 #ifndef	__
 # ifdef __STDC__
@@ -744,23 +745,38 @@ FILE *verboselog;
 	  static char *warning_lines[] = {
 "X-Warning: Original message contained 8-bit characters, however during",
 "           the SMTP transport session the receiving system was unable to",
-"           announce capability of receiving 8-bit SMTP (RFC 1425-1428),",
-"           and as this message does not have MIME headers (RFC 1341) to",
-"           enable encoding change, we had very little choices.",
-"X-Warning: We ASSUME it is less harmfull to add the MIME headers, and",
+"           announce capability of receiving 8-bit SMTP (RFC 1651-1653),",
+"           and as this message does not have MIME headers (RFC 2045-2049)",
+"           to enable encoding change, we had very little choices.",
+"X-Warning: We ASSUME it is less harmful to add the MIME headers, and",
 "           convert the text to Quoted-Printable, than not to do so,",
 "           and to strip the message to 7-bits.. (RFC 1428 Appendix A)",
+"X-Warning: We don't know what character set the user used, thus we had to",
+"           write these MIME-headers with our local system default value.",
 "MIME-Version: 1.0",
-"Content-Type: TEXT/PLAIN; charset=UNKNOWN-8BIT",
 "Content-Transfer-Encoding: QUOTED-PRINTABLE",
 NULL };
 
-	  char **newmsgheaders = (char**)emalloc(sizeof(char**)*(lines+12));
+	  char **newmsgheaders = (char**)emalloc(sizeof(char**)*(lines+15));
+	  char *defcharset = getzenv("DEFCHARSET");
+	  char *newct;
+	  if (!defcharset)
+	    defcharset = "ISO-8859-1";
+#ifdef HAVE_ALLOCA
+	  newct = alloca(strlen(defcharset)+2+sizeof("Content-Type: TEXT/PLAIN; charset="));
+#else
+	  newct = emalloc(strlen(defcharset)+2+sizeof("Content-Type: TEXT/PLAIN; charset="));
+#endif
+	  sprintf(newct,"Content-Type: TEXT/PLAIN; charset=%s",defcharset);
 
 	  if (!newmsgheaders) return; /* XX: Auch! */
 
 	  for (lines = 0; warning_lines[lines] != NULL; ++lines)
 	    newmsgheaders[lines] = strdup(warning_lines[lines]);
+	  newmsgheaders[lines++] = strdup(newct);
+#ifndef HAVE_ALLOCA
+	  free(newct);
+#endif
 	  if (CT)	/* XX: This CAN be wrong action for
 			       some esoteric SysV mailers.. */
 	    delete_header(rp,CT);
