@@ -18,30 +18,15 @@
 #include <sys/types.h>
 #include <fcntl.h>
 #include <sys/stat.h>
-#include "syslog.h"
+#include "zsyslog.h"
 #include "mail.h"
 #include "ta.h"
 
 void
-tatimestr(buf,dt)
-char *buf;
-int dt;
-{
-	int hours, mins, secs;
-
-	secs  = dt % 60;
-	dt    = dt / 60;
-	mins  = dt % 60;
-	hours = dt / 60;
-
-	sprintf(buf,"%02d:%02d:%02d", hours, mins, secs);
-}
-
-void
-tasyslog(rp,xdelay,wtthost,stat,msg)
+tasyslog(rp,xdelay,wtthost,wttip,stat,msg)
 struct rcpt *rp;
 int xdelay;
-char *wtthost;
+char *wtthost, *wttip;
 char *stat;
 char *msg;
 {
@@ -68,16 +53,26 @@ char *msg;
     if (s)
       wtthost = s;
   }
-
-  if (strcmp(stat,"ok")==0 || strcmp(stat,"ok2")==0)
+#if 0
+  if (strcmp(stat,"ok")==0) {
     msg = ""; /* Shut up ... */
-
+  } else if (strcmp(stat,"ok2")==0) {
+    msg = ""; /* Shut up ... */
+  }
+#endif
   if (wtthost == NULL)
-    sprintf(linebuf, "%s: to=%.200s, delay=%s, xdelay=%s, mailer=%.200s, stat=%.200s %.400s",
+    sprintf(linebuf, "%s: to=<%.200s>, delay=%s, xdelay=%s, mailer=%.80s, stat=%.80s %.200s",
 	    spoolid, rp->addr->user, delays, xdelays, rp->addr->channel, stat, msg);
-  else
-    sprintf(linebuf, "%s: to=%.200s, delay=%s, xdelay=%s, mailer=%.200s, relay=%s, stat=%.200s %.400s",
-	    spoolid, rp->addr->user, delays, xdelays, rp->addr->channel, wtthost, stat, msg);
+  else {
+    if (wttip != NULL)
+      sprintf(linebuf, "%s: to=<%.200s>, delay=%s, xdelay=%s, mailer=%.80s, relay=%.200s ([%.80s]), stat=%.80s %.200s",
+	    spoolid, rp->addr->user, delays, xdelays, rp->addr->channel,
+	      wtthost, wttip, stat, msg);
+    else
+      sprintf(linebuf, "%s: to=<%.200s>, delay=%s, xdelay=%s, mailer=%.80s, relay=%.200s, stat=%.80s %.200s",
+	      spoolid, rp->addr->user, delays, xdelays, rp->addr->channel,
+	      wtthost, stat, msg);
+  }
 
-  syslog(LOG_INFO, "%s", linebuf);
+  zsyslog((LOG_INFO, "%s", linebuf));
 }
