@@ -10,7 +10,7 @@
 #include "hostenv.h"
 #include <stdio.h>
 #include <sys/param.h>
-#include <syslog.h>
+#include "zsyslog.h"
 
 extern int errno;
 extern char *progname;
@@ -69,10 +69,10 @@ warning(fmt, arg, arg2, arg3, arg4)
 	fprintf(stderr, "\n");
 #if 0 /* Actually DON'T syslog this stuff! */
 	if (!isopen) {
-		openlog(progname, 0, LOG_MAIL);
+	  zopenlog(progname, 0, LOG_MAIL);
 	}
 	errno = e;
-	syslog(LOG_ERR, fmt, arg, arg2, arg3, arg4);
+	zsyslog((LOG_ERR, fmt, arg, arg2, arg3, arg4));
 #endif
 }
 #endif
