@@ -4,7 +4,7 @@
  *	Copyright 1994 by Matti Aarnio -- MIME processings
  */
 
-#define DefCharset "UNKNOWN-8BIT"
+#define DefCharset "ISO-8859-1"
 
 #include "hostenv.h"
 #include <stdio.h>
@@ -17,7 +17,7 @@
 #include <sys/stat.h>
 #include "mail.h"
 #include "malloc.h"
-#include "syslog.h"
+#include "zsyslog.h"
 #include "ta.h"
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
@@ -69,6 +69,7 @@ int	can_8bit = 0;		/* Can do 8-bit stuff! */
 int	keep_header8 = 0;	/* Don't do "MIME-2" to the headers */
 
 int	D_alloc = 0;		/* Memory debugging */
+char    *defcharset;
 
 extern RETSIGTYPE wantout();
 #ifndef MALLOC_TRACE
@@ -230,7 +231,11 @@ main(argc, argv)
 	mailer = argv[optind];
 
 	/* We need this latter on .. */
-	openlog("sm", LOG_PID, LOG_MAIL);
+	zopenlog("sm", LOG_PID, LOG_MAIL);
+
+	defcharset = getzenv("DEFCHARSET");
+	if (!defcharset)
+	  defcharset = DefCharset;
 
 	if ((mp = readsmcf(cf, mailer)) == NULL)
 	  exit(EX_OSFILE);
@@ -262,8 +267,8 @@ main(argc, argv)
 	    *s = 0;
 	  }
 
-	  ctlsticky((char *)NULL, (char *)NULL); /* reset */
-	  dp = ctlopen(file, channel, host, &getout, ctlsticky, NULL);
+	  ctlsticky(NULL, NULL, NULL); /* reset */
+	  dp = ctlopen(file, channel, host, &getout, ctlsticky, NULL, NULL, NULL);
 	  if (dp == NULL) {
 	    printf("#resync %s\n",file);
 	    fflush(stdout);
@@ -371,7 +376,7 @@ deliver(dp, mp, startrp, endrp, verboselog)
 	  rp = startrp;
 	  do {
 	    while (i+2 >= avsize) {
-	      avsize *= 2;
+	      avsize <<= 1;
 	      av = (char **)erealloc((char *)av,
 				     sizeof av[0] * avsize);
 	    }
@@ -615,7 +620,7 @@ deliver(dp, mp, startrp, endrp, verboselog)
 	  }
 	  
 	  if (!keep_header8 && headers_need_mime2(startrp)) {
-	    headers_to_mime2(startrp,DefCharset,verboselog);
+	    headers_to_mime2(startrp,defcharset,verboselog);
 	  }
 	}
 
@@ -724,7 +729,7 @@ deliver(dp, mp, startrp, endrp, verboselog)
  */
 
 #ifndef	HAVE_MMAP
-static char let_buffer[BUFSIZ];
+static char let_buffer[BUFSIZ*8];
 #endif
 
 int
@@ -784,6 +789,12 @@ appendlet(dp, mp, fp, verboselog, convertmode)
 #ifndef	HAVE_MMAP
 	  }
 #endif
+
+#ifndef HAVE_MMAP
+	  if (bufferfull > 1)	/* not all in memory, need to reread */
+	    readalready = 0;
+#endif
+
 	} else {
 	  /* convertmode something else, than _CONVERT_NONE */
 	  /* Various esoteric conversion modes..
@@ -854,10 +865,6 @@ appendlet(dp, mp, fp, verboselog, convertmode)
 	if (lastch != '\n')
 	  writebuf(mp, fp, "\n", 1);
 
-#ifndef HAVE_MMAP
-	if (bufferfull > 1)	/* not all in memory, need to reread */
-	  readalready = 0;
-#endif
 	return EX_OK;
 }
 
