@@ -4,6 +4,9 @@
  *  rc  = 0: Works
  *  rc != 0: fault
  *
+ * Written at, and used at DEC OSF/1 v3.2 only...
+ * ... that is, your mileage may vary..
+ *
  * By Matti Aarnio <mea@nic.funet.fi> 1995
  */
 
@@ -14,8 +17,6 @@
 #include <pwd.h>
 #include "zmsignal.h"
 #include <sysexits.h>
-/* #include <strings.h> */ /* poorly portable.. */
-#include <varargs.h>
 #include <fcntl.h>
 #include <sys/file.h>
 #include <sys/param.h>
