@@ -75,7 +75,7 @@ int errno;
 }
 
 
-char linebuf[64*1024]; /* 64 kB for SINGLE line is rather much :-) */
+char inputline[64*1024]; /* 64 kB for SINGLE line is rather much :-) */
 
 void
 create_dbase(infile,dbf,typ)
@@ -97,15 +97,15 @@ create_dbase(infile,dbf,typ)
 
 
 	while (!feof(infile) && !ferror(infile)) {
-	  *linebuf = 0;
-	  fgets(linebuf,sizeof(linebuf)-1,infile);
-	  if (*linebuf == 0) break; /* Last! */
-	  s = (char *)strchr(linebuf,'\n');
+	  *inputline = 0;
+	  fgets(inputline,sizeof(inputline)-1,infile);
+	  if (*inputline == 0) break; /* Last! */
+	  s = (char *)strchr(inputline,'\n');
 	  if (s) *s = 0; /* Zap \n from the end -- if it exists.. */
-	  if (*linebuf == '#') continue; /* Comment! */
+	  if (*inputline == '#') continue; /* Comment! */
 
 	  /* Scan first white-space separated token, point its start with t! */
-	  t = linebuf;
+	  t = inputline;
 	  while (*t == '\t' || *t == ' ') ++t;
 
 	  if (*t == 0) continue; /* Blank line! */
